package crontab

import (
	"encoding/json"
	"fmt"
	"kpt-pasture/model"
	"kpt-pasture/util"
	"sort"
	"testing"
	"time"
)

func TestCalculateCFT(t *testing.T) {
	/*neckActiveHabitList := make([]*model.NeckActiveHabit, 0)
	str := `[
	    {
	        "id": 1725734,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 166,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 34,
	        "intake": 51,
	        "inactive": 49,
	        "gasp": 0,
	        "other": 0,
	        "high": 2119,
	        "active": 81,
	        "filterHigh": 43,
	        "filterRumina": 16,
	        "filterChew": 16,
	        "weekHigh": 1500,
	        "weekHighHabit": 268,
	        "weekRuminaHabit": 10,
	        "weekIntakeHabit": 24,
	        "weekChewHabit": 14,
	        "weekInactiveHabit": 24,
	        "weekOtherHabit": 0,
	        "changeHigh": -19,
	        "changeRumina": 60,
	        "changeChew": 14,
	        "changeAdjust": -19,
	        "changeFilter": -6,
	        "ruminaFilter": 18,
	        "chewFilter": 4,
	        "filterCorrect": 97,
	        "sumRumina": 62,
	        "sumIntake": 269,
	        "sumInactive": 445,
	        "sumActive": 659,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 70,
	        "beforeThreeSumIntake": 200,
	        "score": 97,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740414165,
	        "updatedAt": 1740466954
	    },
	    {
	        "id": 1725740,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 61,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 61,
	        "intake": 8,
	        "inactive": 48,
	        "gasp": 0,
	        "other": 0,
	        "high": 1851,
	        "active": 59,
	        "filterHigh": 326,
	        "filterRumina": 27,
	        "filterChew": 35,
	        "weekHigh": 1500,
	        "weekHighHabit": 744,
	        "weekRuminaHabit": 16,
	        "weekIntakeHabit": 19,
	        "weekChewHabit": 23,
	        "weekInactiveHabit": 19,
	        "weekOtherHabit": 0,
	        "changeHigh": -33,
	        "changeRumina": 69,
	        "changeChew": 52,
	        "changeAdjust": 0,
	        "changeFilter": -10,
	        "ruminaFilter": 10,
	        "chewFilter": 16,
	        "filterCorrect": 95,
	        "sumRumina": 120,
	        "sumIntake": 235,
	        "sumInactive": 605,
	        "sumActive": 623,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 105,
	        "beforeThreeSumIntake": 272,
	        "score": 96,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740415350,
	        "updatedAt": 1740466954
	    },
	    {
	        "id": 1725743,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 5,
	        "intake": 12,
	        "inactive": 31,
	        "gasp": 0,
	        "other": 0,
	        "high": 2273,
	        "active": 86,
	        "filterHigh": 513,
	        "filterRumina": 3,
	        "filterChew": 8,
	        "weekHigh": 1500,
	        "weekHighHabit": 878,
	        "weekRuminaHabit": 12,
	        "weekIntakeHabit": 29,
	        "weekChewHabit": 22,
	        "weekInactiveHabit": 29,
	        "weekOtherHabit": 0,
	        "changeHigh": -28,
	        "changeRumina": -75,
	        "changeChew": -64,
	        "changeAdjust": 0,
	        "changeFilter": -7,
	        "ruminaFilter": -9,
	        "chewFilter": -10,
	        "filterCorrect": 97,
	        "sumRumina": 61,
	        "sumIntake": 220,
	        "sumInactive": 632,
	        "sumActive": 504,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 140,
	        "beforeThreeSumIntake": 206,
	        "score": 97,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740415395,
	        "updatedAt": 1740466954
	    },
	    {
	        "id": 1725746,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 299,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 7,
	        "intake": 23,
	        "inactive": 11,
	        "gasp": 0,
	        "other": 0,
	        "high": 3126,
	        "active": 109,
	        "filterHigh": 1004,
	        "filterRumina": 9,
	        "filterChew": 24,
	        "weekHigh": 1500,
	        "weekHighHabit": 802,
	        "weekRuminaHabit": 8,
	        "weekIntakeHabit": 12,
	        "weekChewHabit": 18,
	        "weekInactiveHabit": 12,
	        "weekOtherHabit": 0,
	        "changeHigh": 16,
	        "changeRumina": 13,
	        "changeChew": 33,
	        "changeAdjust": 0,
	        "changeFilter": 5,
	        "ruminaFilter": 4,
	        "chewFilter": 10,
	        "filterCorrect": 95,
	        "sumRumina": 123,
	        "sumIntake": 271,
	        "sumInactive": 563,
	        "sumActive": 569,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 15,
	        "SumMinChew": 7,
	        "beforeThreeSumRumina": 175,
	        "beforeThreeSumIntake": 275,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740415655,
	        "updatedAt": 1740466954
	    },
	    {
	        "id": 1725748,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 299,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 38,
	        "intake": 13,
	        "inactive": 33,
	        "gasp": 0,
	        "other": 0,
	        "high": 2514,
	        "active": 81,
	        "filterHigh": 270,
	        "filterRumina": 18,
	        "filterChew": 22,
	        "weekHigh": 1500,
	        "weekHighHabit": 336,
	        "weekRuminaHabit": 20,
	        "weekIntakeHabit": 17,
	        "weekChewHabit": 27,
	        "weekInactiveHabit": 17,
	        "weekOtherHabit": 0,
	        "changeHigh": -6,
	        "changeRumina": -10,
	        "changeChew": -19,
	        "changeAdjust": 0,
	        "changeFilter": -2,
	        "ruminaFilter": -3,
	        "chewFilter": -6,
	        "filterCorrect": 97,
	        "sumRumina": 159,
	        "sumIntake": 254,
	        "sumInactive": 637,
	        "sumActive": 587,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 3,
	        "beforeThreeSumRumina": 139,
	        "beforeThreeSumIntake": 251,
	        "score": 99,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740415655,
	        "updatedAt": 1740466954
	    },
	    {
	        "id": 1725749,
	        "pastureId": 1,
	        "neckRingNumber": "10038",
	        "cowId": 94,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 0,
	        "intake": 0,
	        "inactive": 41,
	        "gasp": 0,
	        "other": 0,
	        "high": 76,
	        "active": 3,
	        "filterHigh": 28,
	        "filterRumina": 1,
	        "filterChew": 1,
	        "weekHigh": 1500,
	        "weekHighHabit": 430,
	        "weekRuminaHabit": 9,
	        "weekIntakeHabit": 25,
	        "weekChewHabit": 12,
	        "weekInactiveHabit": 25,
	        "weekOtherHabit": 0,
	        "changeHigh": -34,
	        "changeRumina": -89,
	        "changeChew": -92,
	        "changeAdjust": 0,
	        "changeFilter": 0,
	        "ruminaFilter": 0,
	        "chewFilter": 0,
	        "filterCorrect": 98,
	        "sumRumina": 11,
	        "sumIntake": 0,
	        "sumInactive": 432,
	        "sumActive": 153,
	        "sumMinHigh": -7,
	        "sumMaxHigh": 1,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 58,
	        "beforeThreeSumIntake": 252,
	        "score": 68,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740415660,
	        "updatedAt": 1740466954
	    },
	    {
	        "id": 1725756,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 25,
	        "intake": 17,
	        "inactive": 51,
	        "gasp": 0,
	        "other": 0,
	        "high": 1263,
	        "active": 54,
	        "filterHigh": 318,
	        "filterRumina": 8,
	        "filterChew": 19,
	        "weekHigh": 1500,
	        "weekHighHabit": 511,
	        "weekRuminaHabit": 15,
	        "weekIntakeHabit": 21,
	        "weekChewHabit": 29,
	        "weekInactiveHabit": 21,
	        "weekOtherHabit": 0,
	        "changeHigh": -16,
	        "changeRumina": -47,
	        "changeChew": -34,
	        "changeAdjust": 0,
	        "changeFilter": -4,
	        "ruminaFilter": -11,
	        "chewFilter": -10,
	        "filterCorrect": 96,
	        "sumRumina": 140,
	        "sumIntake": 293,
	        "sumInactive": 709,
	        "sumActive": 578,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 19,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 183,
	        "beforeThreeSumIntake": 266,
	        "score": 98,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740416500,
	        "updatedAt": 1740466954
	    },
	    {
	        "id": 1725759,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 01:00:00",
	        "frameid": 0,
	        "heatDate": "2025-02-25",
	        "rumina": 23,
	        "intake": 43,
	        "inactive": 5,
	        "gasp": 0,
	        "other": 0,
	        "high": 2761,
	        "active": 100,
	        "filterHigh": 1279,
	        "filterRumina": 10,
	        "filterChew": 20,
	        "weekHigh": 1500,
	        "weekHighHabit": 1121,
	        "weekRuminaHabit": 8,
	        "weekIntakeHabit": 30,
	        "weekChewHabit": 16,
	        "weekInactiveHabit": 30,
	        "weekOtherHabit": 0,
	        "changeHigh": 12,
	        "changeRumina": 25,
	        "changeChew": 25,
	        "changeAdjust": 0,
	        "changeFilter": 3,
	        "ruminaFilter": 6,
	        "chewFilter": 8,
	        "filterCorrect": 94,
	        "sumRumina": 121,
	        "sumIntake": 268,
	        "sumInactive": 644,
	        "sumActive": 621,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 121,
	        "beforeThreeSumIntake": 205,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740416525,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725764,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 167,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 36,
	        "intake": 20,
	        "inactive": 20,
	        "gasp": 0,
	        "other": 0,
	        "high": 2019,
	        "active": 77,
	        "filterHigh": 318,
	        "filterRumina": 7,
	        "filterChew": 8,
	        "weekHigh": 1500,
	        "weekHighHabit": 356,
	        "weekRuminaHabit": 5,
	        "weekIntakeHabit": 20,
	        "weekChewHabit": 10,
	        "weekInactiveHabit": 20,
	        "weekOtherHabit": 0,
	        "changeHigh": -3,
	        "changeRumina": 40,
	        "changeChew": -20,
	        "changeAdjust": 0,
	        "changeFilter": -1,
	        "ruminaFilter": 12,
	        "chewFilter": -6,
	        "filterCorrect": 97,
	        "sumRumina": 69,
	        "sumIntake": 303,
	        "sumInactive": 517,
	        "sumActive": 674,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 71,
	        "beforeThreeSumIntake": 241,
	        "score": 99,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740421320,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725771,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 62,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 4,
	        "intake": 31,
	        "inactive": 46,
	        "gasp": 0,
	        "other": 0,
	        "high": 2875,
	        "active": 73,
	        "filterHigh": 1212,
	        "filterRumina": 0,
	        "filterChew": 12,
	        "weekHigh": 1500,
	        "weekHighHabit": 1042,
	        "weekRuminaHabit": 2,
	        "weekIntakeHabit": 32,
	        "weekChewHabit": 18,
	        "weekInactiveHabit": 32,
	        "weekOtherHabit": 0,
	        "changeHigh": 13,
	        "changeRumina": -100,
	        "changeChew": -33,
	        "changeAdjust": 0,
	        "changeFilter": 4,
	        "ruminaFilter": -15,
	        "chewFilter": -10,
	        "filterCorrect": 95,
	        "sumRumina": 120,
	        "sumIntake": 237,
	        "sumInactive": 567,
	        "sumActive": 666,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 102,
	        "beforeThreeSumIntake": 253,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740422555,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725774,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 65,
	        "intake": 16,
	        "inactive": 66,
	        "gasp": 0,
	        "other": 0,
	        "high": 1436,
	        "active": 50,
	        "filterHigh": 382,
	        "filterRumina": 17,
	        "filterChew": 21,
	        "weekHigh": 1500,
	        "weekHighHabit": 138,
	        "weekRuminaHabit": 13,
	        "weekIntakeHabit": 8,
	        "weekChewHabit": 10,
	        "weekInactiveHabit": 8,
	        "weekOtherHabit": 0,
	        "changeHigh": 21,
	        "changeRumina": 31,
	        "changeChew": 110,
	        "changeAdjust": 0,
	        "changeFilter": 6,
	        "ruminaFilter": 9,
	        "chewFilter": 16,
	        "filterCorrect": 95,
	        "sumRumina": 131,
	        "sumIntake": 277,
	        "sumInactive": 566,
	        "sumActive": 655,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 15,
	        "SumMinChew": 7,
	        "beforeThreeSumRumina": 193,
	        "beforeThreeSumIntake": 290,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740422555,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725778,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 0,
	        "intake": 46,
	        "inactive": 49,
	        "gasp": 0,
	        "other": 0,
	        "high": 1726,
	        "active": 55,
	        "filterHigh": 1027,
	        "filterRumina": 0,
	        "filterChew": 25,
	        "weekHigh": 1500,
	        "weekHighHabit": 689,
	        "weekRuminaHabit": 9,
	        "weekIntakeHabit": 27,
	        "weekChewHabit": 21,
	        "weekInactiveHabit": 27,
	        "weekOtherHabit": 0,
	        "changeHigh": 27,
	        "changeRumina": -100,
	        "changeChew": 19,
	        "changeAdjust": 0,
	        "changeFilter": 6,
	        "ruminaFilter": -12,
	        "chewFilter": 6,
	        "filterCorrect": 97,
	        "sumRumina": 56,
	        "sumIntake": 242,
	        "sumInactive": 576,
	        "sumActive": 587,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 136,
	        "beforeThreeSumIntake": 224,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740422595,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725782,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 27,
	        "intake": 64,
	        "inactive": 12,
	        "gasp": 0,
	        "other": 0,
	        "high": 2781,
	        "active": 96,
	        "filterHigh": 592,
	        "filterRumina": 17,
	        "filterChew": 21,
	        "weekHigh": 1500,
	        "weekHighHabit": 807,
	        "weekRuminaHabit": 7,
	        "weekIntakeHabit": 37,
	        "weekChewHabit": 21,
	        "weekInactiveHabit": 37,
	        "weekOtherHabit": 0,
	        "changeHigh": -17,
	        "changeRumina": 143,
	        "changeChew": 0,
	        "changeAdjust": 0,
	        "changeFilter": -5,
	        "ruminaFilter": 21,
	        "chewFilter": 0,
	        "filterCorrect": 97,
	        "sumRumina": 176,
	        "sumIntake": 243,
	        "sumInactive": 659,
	        "sumActive": 642,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 3,
	        "beforeThreeSumRumina": 130,
	        "beforeThreeSumIntake": 265,
	        "score": 98,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740422850,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725784,
	        "pastureId": 1,
	        "neckRingNumber": "10038",
	        "cowId": 94,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 1,
	        "intake": 0,
	        "inactive": 43,
	        "gasp": 0,
	        "other": 0,
	        "high": 266,
	        "active": 11,
	        "filterHigh": 24,
	        "filterRumina": 0,
	        "filterChew": 0,
	        "weekHigh": 1500,
	        "weekHighHabit": 145,
	        "weekRuminaHabit": 4,
	        "weekIntakeHabit": 6,
	        "weekChewHabit": 9,
	        "weekInactiveHabit": 6,
	        "weekOtherHabit": 0,
	        "changeHigh": -11,
	        "changeRumina": -100,
	        "changeChew": -100,
	        "changeAdjust": 0,
	        "changeFilter": -3,
	        "ruminaFilter": -12,
	        "chewFilter": -15,
	        "filterCorrect": 98,
	        "sumRumina": 11,
	        "sumIntake": 0,
	        "sumInactive": 513,
	        "sumActive": 149,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 1,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 0,
	        "beforeThreeSumIntake": 0,
	        "score": 68,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740422915,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725786,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 50,
	        "intake": 3,
	        "inactive": 96,
	        "gasp": 0,
	        "other": 0,
	        "high": 763,
	        "active": 28,
	        "filterHigh": 532,
	        "filterRumina": 14,
	        "filterChew": 16,
	        "weekHigh": 1500,
	        "weekHighHabit": 471,
	        "weekRuminaHabit": 13,
	        "weekIntakeHabit": 19,
	        "weekChewHabit": 24,
	        "weekInactiveHabit": 19,
	        "weekOtherHabit": 0,
	        "changeHigh": 5,
	        "changeRumina": 8,
	        "changeChew": -33,
	        "changeAdjust": 0,
	        "changeFilter": 1,
	        "ruminaFilter": 2,
	        "chewFilter": -10,
	        "filterCorrect": 96,
	        "sumRumina": 140,
	        "sumIntake": 272,
	        "sumInactive": 734,
	        "sumActive": 606,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 19,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 181,
	        "beforeThreeSumIntake": 294,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740423705,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725789,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 03:00:00",
	        "frameid": 1,
	        "heatDate": "2025-02-25",
	        "rumina": 45,
	        "intake": 33,
	        "inactive": 2,
	        "gasp": 0,
	        "other": 0,
	        "high": 1855,
	        "active": 66,
	        "filterHigh": 1145,
	        "filterRumina": 11,
	        "filterChew": 31,
	        "weekHigh": 1500,
	        "weekHighHabit": 499,
	        "weekRuminaHabit": 7,
	        "weekIntakeHabit": 23,
	        "weekChewHabit": 14,
	        "weekInactiveHabit": 23,
	        "weekOtherHabit": 0,
	        "changeHigh": 53,
	        "changeRumina": 57,
	        "changeChew": 121,
	        "changeAdjust": 0,
	        "changeFilter": 13,
	        "ruminaFilter": 14,
	        "chewFilter": 18,
	        "filterCorrect": 94,
	        "sumRumina": 132,
	        "sumIntake": 328,
	        "sumInactive": 631,
	        "sumActive": 688,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 120,
	        "beforeThreeSumIntake": 265,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740423730,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725794,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 167,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 41,
	        "intake": 11,
	        "inactive": 106,
	        "gasp": 0,
	        "other": 0,
	        "high": 485,
	        "active": 18,
	        "filterHigh": 327,
	        "filterRumina": 1,
	        "filterChew": 9,
	        "weekHigh": 1500,
	        "weekHighHabit": 143,
	        "weekRuminaHabit": 7,
	        "weekIntakeHabit": 5,
	        "weekChewHabit": 7,
	        "weekInactiveHabit": 5,
	        "weekOtherHabit": 0,
	        "changeHigh": 16,
	        "changeRumina": -86,
	        "changeChew": 29,
	        "changeAdjust": 0,
	        "changeFilter": 5,
	        "ruminaFilter": -13,
	        "chewFilter": 9,
	        "filterCorrect": 97,
	        "sumRumina": 57,
	        "sumIntake": 333,
	        "sumInactive": 521,
	        "sumActive": 738,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 62,
	        "beforeThreeSumIntake": 241,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740428520,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725801,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 65,
	        "intake": 0,
	        "inactive": 116,
	        "gasp": 0,
	        "other": 0,
	        "high": 160,
	        "active": 6,
	        "filterHigh": 29,
	        "filterRumina": 9,
	        "filterChew": 9,
	        "weekHigh": 1500,
	        "weekHighHabit": 22,
	        "weekRuminaHabit": 18,
	        "weekIntakeHabit": 1,
	        "weekChewHabit": 18,
	        "weekInactiveHabit": 1,
	        "weekOtherHabit": 0,
	        "changeHigh": 1,
	        "changeRumina": -50,
	        "changeChew": -50,
	        "changeAdjust": 0,
	        "changeFilter": 0,
	        "ruminaFilter": -15,
	        "chewFilter": -15,
	        "filterCorrect": 97,
	        "sumRumina": 182,
	        "sumIntake": 300,
	        "sumInactive": 638,
	        "sumActive": 698,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 142,
	        "beforeThreeSumIntake": 291,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740429745,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725802,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 36,
	        "intake": 0,
	        "inactive": 115,
	        "gasp": 0,
	        "other": 0,
	        "high": 199,
	        "active": 7,
	        "filterHigh": 31,
	        "filterRumina": 0,
	        "filterChew": 0,
	        "weekHigh": 1500,
	        "weekHighHabit": 407,
	        "weekRuminaHabit": 5,
	        "weekIntakeHabit": 32,
	        "weekChewHabit": 14,
	        "weekInactiveHabit": 32,
	        "weekOtherHabit": 0,
	        "changeHigh": -32,
	        "changeRumina": -100,
	        "changeChew": -100,
	        "changeAdjust": 0,
	        "changeFilter": -10,
	        "ruminaFilter": -15,
	        "chewFilter": -15,
	        "filterCorrect": 95,
	        "sumRumina": 108,
	        "sumIntake": 285,
	        "sumInactive": 583,
	        "sumActive": 688,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 15,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 190,
	        "beforeThreeSumIntake": 220,
	        "score": 96,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740429750,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725805,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 62,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 92,
	        "intake": 0,
	        "inactive": 108,
	        "gasp": 1,
	        "other": 0,
	        "high": 260,
	        "active": 14,
	        "filterHigh": 41,
	        "filterRumina": 24,
	        "filterChew": 24,
	        "weekHigh": 1500,
	        "weekHighHabit": 39,
	        "weekRuminaHabit": 18,
	        "weekIntakeHabit": 0,
	        "weekChewHabit": 18,
	        "weekInactiveHabit": 0,
	        "weekOtherHabit": 0,
	        "changeHigh": 0,
	        "changeRumina": 33,
	        "changeChew": 33,
	        "changeAdjust": 0,
	        "changeFilter": 0,
	        "ruminaFilter": 10,
	        "chewFilter": 10,
	        "filterCorrect": 95,
	        "sumRumina": 134,
	        "sumIntake": 251,
	        "sumInactive": 533,
	        "sumActive": 695,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 102,
	        "beforeThreeSumIntake": 260,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740429755,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725807,
	        "pastureId": 1,
	        "neckRingNumber": "10038",
	        "cowId": 94,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 0,
	        "intake": 0,
	        "inactive": 18,
	        "gasp": 0,
	        "other": 0,
	        "high": 230,
	        "active": 9,
	        "filterHigh": 162,
	        "filterRumina": 0,
	        "filterChew": 0,
	        "weekHigh": 1500,
	        "weekHighHabit": 23,
	        "weekRuminaHabit": 8,
	        "weekIntakeHabit": 0,
	        "weekChewHabit": 8,
	        "weekInactiveHabit": 0,
	        "weekOtherHabit": 0,
	        "changeHigh": 12,
	        "changeRumina": -100,
	        "changeChew": -100,
	        "changeAdjust": 0,
	        "changeFilter": 3,
	        "ruminaFilter": -12,
	        "chewFilter": -15,
	        "filterCorrect": 98,
	        "sumRumina": 11,
	        "sumIntake": 0,
	        "sumInactive": 515,
	        "sumActive": 162,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 1,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 31,
	        "beforeThreeSumIntake": 240,
	        "score": 70,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740429780,
	        "updatedAt": 1740466955
	    },
	    {
	        "id": 1725810,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 59,
	        "intake": 0,
	        "inactive": 104,
	        "gasp": 0,
	        "other": 0,
	        "high": 370,
	        "active": 11,
	        "filterHigh": 149,
	        "filterRumina": 9,
	        "filterChew": 9,
	        "weekHigh": 1500,
	        "weekHighHabit": 123,
	        "weekRuminaHabit": 12,
	        "weekIntakeHabit": 16,
	        "weekChewHabit": 14,
	        "weekInactiveHabit": 16,
	        "weekOtherHabit": 0,
	        "changeHigh": 2,
	        "changeRumina": -25,
	        "changeChew": -36,
	        "changeAdjust": 0,
	        "changeFilter": 0,
	        "ruminaFilter": -6,
	        "chewFilter": -11,
	        "filterCorrect": 97,
	        "sumRumina": 47,
	        "sumIntake": 227,
	        "sumInactive": 578,
	        "sumActive": 572,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 138,
	        "beforeThreeSumIntake": 211,
	        "score": 90,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740429795,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725815,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 45,
	        "intake": 48,
	        "inactive": 54,
	        "gasp": 0,
	        "other": 0,
	        "high": 1908,
	        "active": 69,
	        "filterHigh": 148,
	        "filterRumina": 26,
	        "filterChew": 26,
	        "weekHigh": 1500,
	        "weekHighHabit": 191,
	        "weekRuminaHabit": 15,
	        "weekIntakeHabit": 28,
	        "weekChewHabit": 20,
	        "weekInactiveHabit": 28,
	        "weekOtherHabit": 0,
	        "changeHigh": -4,
	        "changeRumina": 73,
	        "changeChew": 30,
	        "changeAdjust": 0,
	        "changeFilter": -1,
	        "ruminaFilter": 9,
	        "chewFilter": 9,
	        "filterCorrect": 96,
	        "sumRumina": 154,
	        "sumIntake": 272,
	        "sumInactive": 740,
	        "sumActive": 611,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 19,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 179,
	        "beforeThreeSumIntake": 247,
	        "score": 99,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740430900,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725819,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 05:00:00",
	        "frameid": 2,
	        "heatDate": "2025-02-25",
	        "rumina": 36,
	        "intake": 0,
	        "inactive": 84,
	        "gasp": 0,
	        "other": 0,
	        "high": 490,
	        "active": 41,
	        "filterHigh": 76,
	        "filterRumina": 0,
	        "filterChew": 0,
	        "weekHigh": 1500,
	        "weekHighHabit": 590,
	        "weekRuminaHabit": 14,
	        "weekIntakeHabit": 23,
	        "weekChewHabit": 23,
	        "weekInactiveHabit": 23,
	        "weekOtherHabit": 0,
	        "changeHigh": -42,
	        "changeRumina": -100,
	        "changeChew": -100,
	        "changeAdjust": 0,
	        "changeFilter": -10,
	        "ruminaFilter": -12,
	        "chewFilter": -15,
	        "filterCorrect": 94,
	        "sumRumina": 107,
	        "sumIntake": 331,
	        "sumInactive": 562,
	        "sumActive": 699,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 136,
	        "beforeThreeSumIntake": 254,
	        "score": 96,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740430925,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725824,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 167,
	        "activeTime": "2025-02-25 07:00:00",
	        "frameid": 3,
	        "heatDate": "2025-02-25",
	        "rumina": 82,
	        "intake": 0,
	        "inactive": 109,
	        "gasp": 0,
	        "other": 0,
	        "high": 232,
	        "active": 8,
	        "filterHigh": 168,
	        "filterRumina": 9,
	        "filterChew": 9,
	        "weekHigh": 1500,
	        "weekHighHabit": 28,
	        "weekRuminaHabit": 7,
	        "weekIntakeHabit": 28,
	        "weekChewHabit": 7,
	        "weekInactiveHabit": 28,
	        "weekOtherHabit": 0,
	        "changeHigh": 13,
	        "changeRumina": 29,
	        "changeChew": 29,
	        "changeAdjust": 0,
	        "changeFilter": 4,
	        "ruminaFilter": 9,
	        "chewFilter": 9,
	        "filterCorrect": 97,
	        "sumRumina": 66,
	        "sumIntake": 293,
	        "sumInactive": 560,
	        "sumActive": 700,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 62,
	        "beforeThreeSumIntake": 198,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740435720,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725831,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 07:00:00",
	        "frameid": 3,
	        "heatDate": "2025-02-25",
	        "rumina": 91,
	        "intake": 0,
	        "inactive": 110,
	        "gasp": 0,
	        "other": 0,
	        "high": 214,
	        "active": 10,
	        "filterHigh": 121,
	        "filterRumina": 27,
	        "filterChew": 27,
	        "weekHigh": 1500,
	        "weekHighHabit": 27,
	        "weekRuminaHabit": 24,
	        "weekIntakeHabit": 3,
	        "weekChewHabit": 24,
	        "weekInactiveHabit": 3,
	        "weekOtherHabit": 0,
	        "changeHigh": 8,
	        "changeRumina": 13,
	        "changeChew": 13,
	        "changeAdjust": 0,
	        "changeFilter": 2,
	        "ruminaFilter": 4,
	        "chewFilter": 4,
	        "filterCorrect": 97,
	        "sumRumina": 182,
	        "sumIntake": 297,
	        "sumInactive": 638,
	        "sumActive": 694,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 128,
	        "beforeThreeSumIntake": 291,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740436955,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725832,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 62,
	        "activeTime": "2025-02-25 07:00:00",
	        "frameid": 3,
	        "heatDate": "2025-02-25",
	        "rumina": 95,
	        "intake": 0,
	        "inactive": 110,
	        "gasp": 0,
	        "other": 0,
	        "high": 264,
	        "active": 16,
	        "filterHigh": 144,
	        "filterRumina": 23,
	        "filterChew": 23,
	        "weekHigh": 1500,
	        "weekHighHabit": 55,
	        "weekRuminaHabit": 19,
	        "weekIntakeHabit": 9,
	        "weekChewHabit": 20,
	        "weekInactiveHabit": 9,
	        "weekOtherHabit": 0,
	        "changeHigh": 8,
	        "changeRumina": 21,
	        "changeChew": 15,
	        "changeAdjust": 0,
	        "changeFilter": 2,
	        "ruminaFilter": 6,
	        "chewFilter": 4,
	        "filterCorrect": 95,
	        "sumRumina": 143,
	        "sumIntake": 251,
	        "sumInactive": 579,
	        "sumActive": 706,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 78,
	        "beforeThreeSumIntake": 260,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740436960,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725839,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 07:00:00",
	        "frameid": 3,
	        "heatDate": "2025-02-25",
	        "rumina": 13,
	        "intake": 0,
	        "inactive": 118,
	        "gasp": 0,
	        "other": 0,
	        "high": 126,
	        "active": 2,
	        "filterHigh": 78,
	        "filterRumina": 3,
	        "filterChew": 3,
	        "weekHigh": 1500,
	        "weekHighHabit": 133,
	        "weekRuminaHabit": 4,
	        "weekIntakeHabit": 13,
	        "weekChewHabit": 7,
	        "weekInactiveHabit": 13,
	        "weekOtherHabit": 0,
	        "changeHigh": -5,
	        "changeRumina": -25,
	        "changeChew": -57,
	        "changeAdjust": 0,
	        "changeFilter": -1,
	        "ruminaFilter": -6,
	        "chewFilter": -17,
	        "filterCorrect": 97,
	        "sumRumina": 50,
	        "sumIntake": 200,
	        "sumInactive": 628,
	        "sumActive": 526,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 0,
	        "beforeThreeSumIntake": 0,
	        "score": 89,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740436990,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725845,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 07:00:00",
	        "frameid": 3,
	        "heatDate": "2025-02-25",
	        "rumina": 33,
	        "intake": 1,
	        "inactive": 112,
	        "gasp": 0,
	        "other": 0,
	        "high": 231,
	        "active": 6,
	        "filterHigh": 127,
	        "filterRumina": 23,
	        "filterChew": 23,
	        "weekHigh": 1500,
	        "weekHighHabit": 91,
	        "weekRuminaHabit": 20,
	        "weekIntakeHabit": 12,
	        "weekChewHabit": 21,
	        "weekInactiveHabit": 12,
	        "weekOtherHabit": 0,
	        "changeHigh": 3,
	        "changeRumina": 15,
	        "changeChew": 10,
	        "changeAdjust": 0,
	        "changeFilter": 1,
	        "ruminaFilter": 4,
	        "chewFilter": 3,
	        "filterCorrect": 96,
	        "sumRumina": 159,
	        "sumIntake": 301,
	        "sumInactive": 700,
	        "sumActive": 646,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 19,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 180,
	        "beforeThreeSumIntake": 286,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740438100,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725849,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 07:00:00",
	        "frameid": 3,
	        "heatDate": "2025-02-25",
	        "rumina": 71,
	        "intake": 9,
	        "inactive": 0,
	        "gasp": 0,
	        "other": 0,
	        "high": 936,
	        "active": 49,
	        "filterHigh": 595,
	        "filterRumina": 18,
	        "filterChew": 24,
	        "weekHigh": 1500,
	        "weekHighHabit": 77,
	        "weekRuminaHabit": 23,
	        "weekIntakeHabit": 7,
	        "weekChewHabit": 23,
	        "weekInactiveHabit": 7,
	        "weekOtherHabit": 0,
	        "changeHigh": 46,
	        "changeRumina": -22,
	        "changeChew": 4,
	        "changeAdjust": 0,
	        "changeFilter": 11,
	        "ruminaFilter": -5,
	        "chewFilter": 1,
	        "filterCorrect": 94,
	        "sumRumina": 109,
	        "sumIntake": 334,
	        "sumInactive": 485,
	        "sumActive": 756,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 126,
	        "beforeThreeSumIntake": 248,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740438130,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725853,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 07:00:00",
	        "frameid": 3,
	        "heatDate": "2025-02-25",
	        "rumina": 3,
	        "intake": 9,
	        "inactive": 105,
	        "gasp": 0,
	        "other": 0,
	        "high": 583,
	        "active": 20,
	        "filterHigh": 16,
	        "filterRumina": 0,
	        "filterChew": 0,
	        "weekHigh": 1500,
	        "weekHighHabit": 341,
	        "weekRuminaHabit": 12,
	        "weekIntakeHabit": 30,
	        "weekChewHabit": 16,
	        "weekInactiveHabit": 30,
	        "weekOtherHabit": 0,
	        "changeHigh": -28,
	        "changeRumina": -100,
	        "changeChew": -100,
	        "changeAdjust": 0,
	        "changeFilter": -8,
	        "ruminaFilter": -15,
	        "chewFilter": -15,
	        "filterCorrect": 95,
	        "sumRumina": 103,
	        "sumIntake": 251,
	        "sumInactive": 654,
	        "sumActive": 633,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 15,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 163,
	        "beforeThreeSumIntake": 255,
	        "score": 96,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740442795,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725854,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 167,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 62,
	        "intake": 1,
	        "inactive": 86,
	        "gasp": 0,
	        "other": 0,
	        "high": 783,
	        "active": 34,
	        "filterHigh": 329,
	        "filterRumina": 7,
	        "filterChew": 7,
	        "weekHigh": 1500,
	        "weekHighHabit": 258,
	        "weekRuminaHabit": 0,
	        "weekIntakeHabit": 40,
	        "weekChewHabit": 10,
	        "weekInactiveHabit": 40,
	        "weekOtherHabit": 0,
	        "changeHigh": 6,
	        "changeRumina": 0,
	        "changeChew": -30,
	        "changeAdjust": 0,
	        "changeFilter": 2,
	        "ruminaFilter": 0,
	        "chewFilter": -9,
	        "filterCorrect": 97,
	        "sumRumina": 73,
	        "sumIntake": 234,
	        "sumInactive": 661,
	        "sumActive": 628,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 3,
	        "beforeThreeSumRumina": 64,
	        "beforeThreeSumIntake": 205,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740442915,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725862,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 62,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 43,
	        "intake": 7,
	        "inactive": 29,
	        "gasp": 0,
	        "other": 0,
	        "high": 2458,
	        "active": 77,
	        "filterHigh": 1077,
	        "filterRumina": 7,
	        "filterChew": 11,
	        "weekHigh": 1500,
	        "weekHighHabit": 892,
	        "weekRuminaHabit": 10,
	        "weekIntakeHabit": 29,
	        "weekChewHabit": 21,
	        "weekInactiveHabit": 29,
	        "weekOtherHabit": 0,
	        "changeHigh": 14,
	        "changeRumina": -30,
	        "changeChew": -48,
	        "changeAdjust": 0,
	        "changeFilter": 4,
	        "ruminaFilter": -9,
	        "chewFilter": -14,
	        "filterCorrect": 95,
	        "sumRumina": 132,
	        "sumIntake": 230,
	        "sumInactive": 648,
	        "sumActive": 681,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 56,
	        "beforeThreeSumIntake": 276,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740444160,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725865,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 0,
	        "intake": 34,
	        "inactive": 31,
	        "gasp": 0,
	        "other": 0,
	        "high": 1540,
	        "active": 71,
	        "filterHigh": 239,
	        "filterRumina": 0,
	        "filterChew": 0,
	        "weekHigh": 1500,
	        "weekHighHabit": 357,
	        "weekRuminaHabit": 3,
	        "weekIntakeHabit": 19,
	        "weekChewHabit": 6,
	        "weekInactiveHabit": 19,
	        "weekOtherHabit": 0,
	        "changeHigh": -10,
	        "changeRumina": -100,
	        "changeChew": -100,
	        "changeAdjust": 0,
	        "changeFilter": -2,
	        "ruminaFilter": -12,
	        "chewFilter": -15,
	        "filterCorrect": 97,
	        "sumRumina": 50,
	        "sumIntake": 186,
	        "sumInactive": 739,
	        "sumActive": 469,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 141,
	        "beforeThreeSumIntake": 215,
	        "score": 89,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740444195,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725870,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 66,
	        "intake": 0,
	        "inactive": 46,
	        "gasp": 0,
	        "other": 0,
	        "high": 1275,
	        "active": 57,
	        "filterHigh": 329,
	        "filterRumina": 18,
	        "filterChew": 18,
	        "weekHigh": 1500,
	        "weekHighHabit": 412,
	        "weekRuminaHabit": 13,
	        "weekIntakeHabit": 18,
	        "weekChewHabit": 20,
	        "weekInactiveHabit": 18,
	        "weekOtherHabit": 0,
	        "changeHigh": -7,
	        "changeRumina": 38,
	        "changeChew": -10,
	        "changeAdjust": 0,
	        "changeFilter": -2,
	        "ruminaFilter": 11,
	        "chewFilter": -3,
	        "filterCorrect": 97,
	        "sumRumina": 200,
	        "sumIntake": 267,
	        "sumInactive": 691,
	        "sumActive": 651,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 10,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 116,
	        "beforeThreeSumIntake": 283,
	        "score": 99,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740444450,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725873,
	        "pastureId": 1,
	        "neckRingNumber": "10038",
	        "cowId": 94,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 4,
	        "intake": 0,
	        "inactive": 0,
	        "gasp": 0,
	        "other": 0,
	        "high": 209,
	        "active": 13,
	        "filterHigh": 77,
	        "filterRumina": 3,
	        "filterChew": 3,
	        "weekHigh": 1500,
	        "weekHighHabit": 359,
	        "weekRuminaHabit": 2,
	        "weekIntakeHabit": 17,
	        "weekChewHabit": 4,
	        "weekInactiveHabit": 17,
	        "weekOtherHabit": 0,
	        "changeHigh": -24,
	        "changeRumina": 50,
	        "changeChew": -25,
	        "changeAdjust": 0,
	        "changeFilter": -6,
	        "ruminaFilter": 12,
	        "chewFilter": -8,
	        "filterCorrect": 98,
	        "sumRumina": 12,
	        "sumIntake": 0,
	        "sumInactive": 502,
	        "sumActive": 132,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 3,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 19,
	        "beforeThreeSumIntake": 157,
	        "score": 67,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740445065,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725874,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 33,
	        "intake": 26,
	        "inactive": 3,
	        "gasp": 0,
	        "other": 0,
	        "high": 2339,
	        "active": 96,
	        "filterHigh": 1061,
	        "filterRumina": 7,
	        "filterChew": 25,
	        "weekHigh": 1500,
	        "weekHighHabit": 475,
	        "weekRuminaHabit": 12,
	        "weekIntakeHabit": 26,
	        "weekChewHabit": 26,
	        "weekInactiveHabit": 26,
	        "weekOtherHabit": 0,
	        "changeHigh": 49,
	        "changeRumina": -42,
	        "changeChew": -4,
	        "changeAdjust": 0,
	        "changeFilter": 12,
	        "ruminaFilter": -10,
	        "chewFilter": -1,
	        "filterCorrect": 96,
	        "sumRumina": 163,
	        "sumIntake": 263,
	        "sumInactive": 763,
	        "sumActive": 589,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 9,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 193,
	        "beforeThreeSumIntake": 284,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740445305,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725879,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 34,
	        "intake": 27,
	        "inactive": 15,
	        "gasp": 0,
	        "other": 0,
	        "high": 1563,
	        "active": 64,
	        "filterHigh": 720,
	        "filterRumina": 23,
	        "filterChew": 27,
	        "weekHigh": 1500,
	        "weekHighHabit": 796,
	        "weekRuminaHabit": 2,
	        "weekIntakeHabit": 26,
	        "weekChewHabit": 7,
	        "weekInactiveHabit": 26,
	        "weekOtherHabit": 0,
	        "changeHigh": -6,
	        "changeRumina": 1050,
	        "changeChew": 286,
	        "changeAdjust": 0,
	        "changeFilter": -1,
	        "ruminaFilter": 50,
	        "chewFilter": 43,
	        "filterCorrect": 94,
	        "sumRumina": 132,
	        "sumIntake": 295,
	        "sumInactive": 473,
	        "sumActive": 719,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 127,
	        "beforeThreeSumIntake": 232,
	        "score": 99,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740445320,
	        "updatedAt": 1740466956
	    },
	    {
	        "id": 1725883,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 09:00:00",
	        "frameid": 4,
	        "heatDate": "2025-02-25",
	        "rumina": 15,
	        "intake": 43,
	        "inactive": 2,
	        "gasp": 0,
	        "other": 0,
	        "high": 2796,
	        "active": 99,
	        "filterHigh": 1259,
	        "filterRumina": 4,
	        "filterChew": 21,
	        "weekHigh": 1500,
	        "weekHighHabit": 598,
	        "weekRuminaHabit": 5,
	        "weekIntakeHabit": 15,
	        "weekChewHabit": 11,
	        "weekInactiveHabit": 15,
	        "weekOtherHabit": 0,
	        "changeHigh": 54,
	        "changeRumina": -20,
	        "changeChew": 91,
	        "changeAdjust": 0,
	        "changeFilter": 16,
	        "ruminaFilter": -6,
	        "chewFilter": 14,
	        "filterCorrect": 95,
	        "sumRumina": 105,
	        "sumIntake": 265,
	        "sumInactive": 717,
	        "sumActive": 651,
	        "sumMinHigh": -13,
	        "sumMaxHigh": 16,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 160,
	        "beforeThreeSumIntake": 282,
	        "score": 97,
	        "isMaxTime": 2,
	        "isShow": 1,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740445670,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725884,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 167,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 35,
	        "intake": 39,
	        "inactive": 1,
	        "gasp": 0,
	        "other": 0,
	        "high": 2761,
	        "active": 95,
	        "filterHigh": 247,
	        "filterRumina": 6,
	        "filterChew": 6,
	        "weekHigh": 1500,
	        "weekHighHabit": 388,
	        "weekRuminaHabit": 1,
	        "weekIntakeHabit": 21,
	        "weekChewHabit": 8,
	        "weekInactiveHabit": 21,
	        "weekOtherHabit": 0,
	        "changeHigh": -12,
	        "changeRumina": 500,
	        "changeChew": -25,
	        "changeAdjust": 0,
	        "changeFilter": -4,
	        "ruminaFilter": 50,
	        "chewFilter": -8,
	        "filterCorrect": 97,
	        "sumRumina": 70,
	        "sumIntake": 210,
	        "sumInactive": 741,
	        "sumActive": 577,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 3,
	        "beforeThreeSumRumina": 68,
	        "beforeThreeSumIntake": 225,
	        "score": 98,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740450120,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725891,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 48,
	        "intake": 41,
	        "inactive": 51,
	        "gasp": 0,
	        "other": 0,
	        "high": 1893,
	        "active": 71,
	        "filterHigh": 803,
	        "filterRumina": 1,
	        "filterChew": 18,
	        "weekHigh": 1500,
	        "weekHighHabit": 719,
	        "weekRuminaHabit": 6,
	        "weekIntakeHabit": 36,
	        "weekChewHabit": 18,
	        "weekInactiveHabit": 36,
	        "weekOtherHabit": 0,
	        "changeHigh": 7,
	        "changeRumina": -83,
	        "changeChew": 0,
	        "changeAdjust": 0,
	        "changeFilter": 2,
	        "ruminaFilter": -12,
	        "chewFilter": 0,
	        "filterCorrect": 97,
	        "sumRumina": 192,
	        "sumIntake": 250,
	        "sumInactive": 697,
	        "sumActive": 640,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 10,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 128,
	        "beforeThreeSumIntake": 246,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740451350,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725894,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 62,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 0,
	        "intake": 45,
	        "inactive": 52,
	        "gasp": 0,
	        "other": 0,
	        "high": 2748,
	        "active": 66,
	        "filterHigh": 1309,
	        "filterRumina": 0,
	        "filterChew": 19,
	        "weekHigh": 1500,
	        "weekHighHabit": 884,
	        "weekRuminaHabit": 5,
	        "weekIntakeHabit": 31,
	        "weekChewHabit": 14,
	        "weekInactiveHabit": 31,
	        "weekOtherHabit": 0,
	        "changeHigh": 33,
	        "changeRumina": -100,
	        "changeChew": 36,
	        "changeAdjust": 0,
	        "changeFilter": 10,
	        "ruminaFilter": -15,
	        "chewFilter": 11,
	        "filterCorrect": 95,
	        "sumRumina": 122,
	        "sumIntake": 214,
	        "sumInactive": 670,
	        "sumActive": 656,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 52,
	        "beforeThreeSumIntake": 277,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740451355,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725896,
	        "pastureId": 1,
	        "neckRingNumber": "10038",
	        "cowId": 94,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 2,
	        "intake": 0,
	        "inactive": 76,
	        "gasp": 0,
	        "other": 0,
	        "high": 249,
	        "active": 6,
	        "filterHigh": 20,
	        "filterRumina": 2,
	        "filterChew": 2,
	        "weekHigh": 1500,
	        "weekHighHabit": 48,
	        "weekRuminaHabit": 7,
	        "weekIntakeHabit": 11,
	        "weekChewHabit": 11,
	        "weekInactiveHabit": 11,
	        "weekOtherHabit": 0,
	        "changeHigh": -3,
	        "changeRumina": -71,
	        "changeChew": -82,
	        "changeAdjust": 0,
	        "changeFilter": -1,
	        "ruminaFilter": -9,
	        "chewFilter": -12,
	        "filterCorrect": 98,
	        "sumRumina": 13,
	        "sumIntake": 0,
	        "sumInactive": 515,
	        "sumActive": 136,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 3,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 20,
	        "beforeThreeSumIntake": 121,
	        "score": 69,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740451385,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725901,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 7,
	        "intake": 24,
	        "inactive": 66,
	        "gasp": 0,
	        "other": 0,
	        "high": 1082,
	        "active": 51,
	        "filterHigh": 365,
	        "filterRumina": 3,
	        "filterChew": 8,
	        "weekHigh": 1500,
	        "weekHighHabit": 113,
	        "weekRuminaHabit": 16,
	        "weekIntakeHabit": 7,
	        "weekChewHabit": 20,
	        "weekInactiveHabit": 7,
	        "weekOtherHabit": 0,
	        "changeHigh": 22,
	        "changeRumina": -81,
	        "changeChew": -60,
	        "changeAdjust": 0,
	        "changeFilter": 0,
	        "ruminaFilter": 0,
	        "chewFilter": 0,
	        "filterCorrect": 97,
	        "sumRumina": 52,
	        "sumIntake": 204,
	        "sumInactive": 686,
	        "sumActive": 506,
	        "sumMinHigh": -11,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 123,
	        "beforeThreeSumIntake": 225,
	        "score": 87,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740451390,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725904,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 48,
	        "intake": 42,
	        "inactive": 68,
	        "gasp": 0,
	        "other": 0,
	        "high": 1135,
	        "active": 49,
	        "filterHigh": 847,
	        "filterRumina": 2,
	        "filterChew": 30,
	        "weekHigh": 1500,
	        "weekHighHabit": 651,
	        "weekRuminaHabit": 13,
	        "weekIntakeHabit": 20,
	        "weekChewHabit": 26,
	        "weekInactiveHabit": 20,
	        "weekOtherHabit": 0,
	        "changeHigh": 16,
	        "changeRumina": -85,
	        "changeChew": 15,
	        "changeAdjust": 0,
	        "changeFilter": 4,
	        "ruminaFilter": -10,
	        "chewFilter": 4,
	        "filterCorrect": 96,
	        "sumRumina": 158,
	        "sumIntake": 299,
	        "sumInactive": 700,
	        "sumActive": 637,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 12,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 193,
	        "beforeThreeSumIntake": 270,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740452505,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725908,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 43,
	        "intake": 25,
	        "inactive": 93,
	        "gasp": 0,
	        "other": 0,
	        "high": 821,
	        "active": 30,
	        "filterHigh": 32,
	        "filterRumina": 29,
	        "filterChew": 29,
	        "weekHigh": 1500,
	        "weekHighHabit": 277,
	        "weekRuminaHabit": 18,
	        "weekIntakeHabit": 11,
	        "weekChewHabit": 24,
	        "weekInactiveHabit": 11,
	        "weekOtherHabit": 0,
	        "changeHigh": -21,
	        "changeRumina": 61,
	        "changeChew": 21,
	        "changeAdjust": 0,
	        "changeFilter": -5,
	        "ruminaFilter": 7,
	        "chewFilter": 6,
	        "filterCorrect": 94,
	        "sumRumina": 144,
	        "sumIntake": 285,
	        "sumInactive": 533,
	        "sumActive": 654,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 127,
	        "beforeThreeSumIntake": 297,
	        "score": 98,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740452530,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725913,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 11:00:00",
	        "frameid": 5,
	        "heatDate": "2025-02-25",
	        "rumina": 64,
	        "intake": 36,
	        "inactive": 67,
	        "gasp": 0,
	        "other": 0,
	        "high": 1391,
	        "active": 57,
	        "filterHigh": 512,
	        "filterRumina": 20,
	        "filterChew": 31,
	        "weekHigh": 1500,
	        "weekHighHabit": 559,
	        "weekRuminaHabit": 4,
	        "weekIntakeHabit": 29,
	        "weekChewHabit": 13,
	        "weekInactiveHabit": 29,
	        "weekOtherHabit": 0,
	        "changeHigh": -4,
	        "changeRumina": 400,
	        "changeChew": 138,
	        "changeAdjust": 0,
	        "changeFilter": -1,
	        "ruminaFilter": 50,
	        "chewFilter": 21,
	        "filterCorrect": 95,
	        "sumRumina": 110,
	        "sumIntake": 264,
	        "sumInactive": 725,
	        "sumActive": 645,
	        "sumMinHigh": -13,
	        "sumMaxHigh": 16,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 157,
	        "beforeThreeSumIntake": 266,
	        "score": 97,
	        "isMaxTime": 2,
	        "isShow": 1,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740452850,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725914,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 167,
	        "activeTime": "2025-02-25 13:00:00",
	        "frameid": 6,
	        "heatDate": "2025-02-25",
	        "rumina": 26,
	        "intake": 27,
	        "inactive": 69,
	        "gasp": 0,
	        "other": 0,
	        "high": 1001,
	        "active": 46,
	        "filterHigh": 349,
	        "filterRumina": 0,
	        "filterChew": 14,
	        "weekHigh": 1500,
	        "weekHighHabit": 200,
	        "weekRuminaHabit": 8,
	        "weekIntakeHabit": 8,
	        "weekChewHabit": 9,
	        "weekInactiveHabit": 8,
	        "weekOtherHabit": 0,
	        "changeHigh": 13,
	        "changeRumina": -100,
	        "changeChew": 56,
	        "changeAdjust": 0,
	        "changeFilter": 4,
	        "ruminaFilter": -15,
	        "chewFilter": 17,
	        "filterCorrect": 97,
	        "sumRumina": 67,
	        "sumIntake": 254,
	        "sumInactive": 674,
	        "sumActive": 627,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 5,
	        "SumMinChew": 3,
	        "beforeThreeSumRumina": 73,
	        "beforeThreeSumIntake": 227,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740457320,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725921,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 13:00:00",
	        "frameid": 6,
	        "heatDate": "2025-02-25",
	        "rumina": 54,
	        "intake": 0,
	        "inactive": 105,
	        "gasp": 0,
	        "other": 0,
	        "high": 198,
	        "active": 10,
	        "filterHigh": 48,
	        "filterRumina": 15,
	        "filterChew": 15,
	        "weekHigh": 1500,
	        "weekHighHabit": 32,
	        "weekRuminaHabit": 13,
	        "weekIntakeHabit": 2,
	        "weekChewHabit": 13,
	        "weekInactiveHabit": 2,
	        "weekOtherHabit": 0,
	        "changeHigh": 1,
	        "changeRumina": 15,
	        "changeChew": 15,
	        "changeAdjust": 0,
	        "changeFilter": 0,
	        "ruminaFilter": 4,
	        "chewFilter": 4,
	        "filterCorrect": 97,
	        "sumRumina": 180,
	        "sumIntake": 266,
	        "sumInactive": 677,
	        "sumActive": 664,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 10,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 128,
	        "beforeThreeSumIntake": 278,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740458550,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725926,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 62,
	        "activeTime": "2025-02-25 13:00:00",
	        "frameid": 6,
	        "heatDate": "2025-02-25",
	        "rumina": 23,
	        "intake": 29,
	        "inactive": 71,
	        "gasp": 0,
	        "other": 0,
	        "high": 1844,
	        "active": 50,
	        "filterHigh": 402,
	        "filterRumina": 16,
	        "filterChew": 19,
	        "weekHigh": 1500,
	        "weekHighHabit": 296,
	        "weekRuminaHabit": 13,
	        "weekIntakeHabit": 12,
	        "weekChewHabit": 17,
	        "weekInactiveHabit": 12,
	        "weekOtherHabit": 0,
	        "changeHigh": 9,
	        "changeRumina": 23,
	        "changeChew": 12,
	        "changeAdjust": 0,
	        "changeFilter": 3,
	        "ruminaFilter": 7,
	        "chewFilter": 4,
	        "filterCorrect": 95,
	        "sumRumina": 121,
	        "sumIntake": 236,
	        "sumInactive": 627,
	        "sumActive": 696,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 68,
	        "beforeThreeSumIntake": 282,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740458585,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725932,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 13:00:00",
	        "frameid": 6,
	        "heatDate": "2025-02-25",
	        "rumina": 66,
	        "intake": 0,
	        "inactive": 111,
	        "gasp": 0,
	        "other": 0,
	        "high": 90,
	        "active": 6,
	        "filterHigh": 4,
	        "filterRumina": 27,
	        "filterChew": 27,
	        "weekHigh": 1500,
	        "weekHighHabit": 216,
	        "weekRuminaHabit": 9,
	        "weekIntakeHabit": 13,
	        "weekChewHabit": 14,
	        "weekInactiveHabit": 13,
	        "weekOtherHabit": 0,
	        "changeHigh": -18,
	        "changeRumina": 200,
	        "changeChew": 93,
	        "changeAdjust": 0,
	        "changeFilter": -4,
	        "ruminaFilter": 24,
	        "chewFilter": 14,
	        "filterCorrect": 97,
	        "sumRumina": 62,
	        "sumIntake": 220,
	        "sumInactive": 664,
	        "sumActive": 530,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 123,
	        "beforeThreeSumIntake": 249,
	        "score": 98,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740458625,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725934,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 13:00:00",
	        "frameid": 6,
	        "heatDate": "2025-02-25",
	        "rumina": 45,
	        "intake": 31,
	        "inactive": 62,
	        "gasp": 0,
	        "other": 0,
	        "high": 1464,
	        "active": 58,
	        "filterHigh": 267,
	        "filterRumina": 14,
	        "filterChew": -13,
	        "changeAdjust": 0,
	        "changeFilter": 3,
	        "ruminaFilter": -7,
	        "chewFilter": -4,
	        "filterCorrect": 96,
	        "sumRumina": 151,
	        "sumIntake": 294,
	        "sumInactive": 715,
	        "sumActive": 625,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 12,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 185,
	        "beforeThreeSumIntake": 253,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740459700,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725938,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 13:00:00",
	        "frameid": 6,
	        "heatDate": "2025-02-25",
	        "rumina": 41,
	        "intake": 13,
	        "inactive": 94,
	        "gasp": 0,
	        "other": 0,
	        "high": 752,
	        "active": 30,
	        "filterHigh": 498,
	        "filterRumina": 17,
	        "filterChew": 25,
	        "weekHigh": 1500,
	        "weekHighHabit": 470,
	        "weekRuminaHabit": 9,
	        "weekIntakeHabit": 27,
	        "weekChewHabit": 22,
	        "weekInactiveHabit": 27,
	        "weekOtherHabit": 0,
	        "changeHigh": 2,
	        "changeRumina": 89,
	        "changeChew": 14,
	        "changeAdjust": 0,
	        "changeFilter": 0,
	        "ruminaFilter": 11,
	        "chewFilter": 4,
	        "filterCorrect": 94,
	        "sumRumina": 146,
	        "sumIntake": 323,
	        "sumInactive": 480,
	        "sumActive": 702,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 126,
	        "beforeThreeSumIntake": 274,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740459725,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725943,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 13:00:00",
	        "frameid": 6,
	        "heatDate": "2025-02-25",
	        "rumina": 30,
	        "intake": 0,
	        "inactive": 109,
	        "gasp": 0,
	        "other": 0,
	        "high": 223,
	        "active": 8,
	        "filterHigh": 162,
	        "filterRumina": 17,
	        "filterChew": 17,
	        "weekHigh": 1500,
	        "weekHighHabit": 639,
	        "weekRuminaHabit": 2,
	        "weekIntakeHabit": 32,
	        "weekChewHabit": 13,
	        "weekInactiveHabit": 32,
	        "weekOtherHabit": 0,
	        "changeHigh": -39,
	        "changeRumina": 750,
	        "changeChew": 31,
	        "changeAdjust": 0,
	        "changeFilter": -12,
	        "ruminaFilter": 50,
	        "chewFilter": 9,
	        "filterCorrect": 95,
	        "sumRumina": 124,
	        "sumIntake": 246,
	        "sumInactive": 821,
	        "sumActive": 597,
	        "sumMinHigh": -13,
	        "sumMaxHigh": 16,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 151,
	        "beforeThreeSumIntake": 244,
	        "score": 95,
	        "isMaxTime": 2,
	        "isShow": 1,
	        "recordCount": 6,
	        "firmwareVersion": 57,
	        "createdAt": 1740460350,
	        "updatedAt": 1740466957
	    },
	    {
	        "id": 1725944,
	        "pastureId": 1,
	        "neckRingNumber": "10054",
	        "cowId": 109,
	        "lact": 3,
	        "calvingAge": 167,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 38,
	        "intake": 20,
	        "inactive": 43,
	        "gasp": 0,
	        "other": 0,
	        "high": 1131,
	        "active": 39,
	        "filterHigh": 1,
	        "filterRumina": 9,
	        "filterChew": 9,
	        "weekHigh": 1500,
	        "weekHighHabit": 110,
	        "weekRuminaHabit": 6,
	        "weekIntakeHabit": 45,
	        "weekChewHabit": 6,
	        "weekInactiveHabit": 45,
	        "weekOtherHabit": 0,
	        "changeHigh": -10,
	        "changeRumina": 50,
	        "changeChew": 50,
	        "changeAdjust": 0,
	        "changeFilter": -3,
	        "ruminaFilter": 15,
	        "chewFilter": 15,
	        "filterCorrect": 97,
	        "sumRumina": 73,
	        "sumIntake": 253,
	        "sumInactive": 695,
	        "sumActive": 606,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 5,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 75,
	        "beforeThreeSumIntake": 196,
	        "score": 98,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 4,
	        "firmwareVersion": 57,
	        "createdAt": 1740464515,
	        "updatedAt": 1740468120
	    },
	    {
	        "id": 1725950,
	        "pastureId": 1,
	        "neckRingNumber": "10030",
	        "cowId": 86,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 50,
	        "intake": 26,
	        "inactive": 62,
	        "gasp": 0,
	        "other": 0,
	        "high": 1140,
	        "active": 43,
	        "filterHigh": 24,
	        "filterRumina": 27,
	        "filterChew": 27,
	        "weekHigh": 1500,
	        "weekHighHabit": 307,
	        "weekRuminaHabit": 8,
	        "weekIntakeHabit": 42,
	        "weekChewHabit": 15,
	        "weekInactiveHabit": 42,
	        "weekOtherHabit": 0,
	        "changeHigh": -24,
	        "changeRumina": 238,
	        "changeChew": 80,
	        "changeAdjust": 0,
	        "changeFilter": -7,
	        "ruminaFilter": 36,
	        "chewFilter": 12,
	        "filterCorrect": 97,
	        "sumRumina": 188,
	        "sumIntake": 238,
	        "sumInactive": 713,
	        "sumActive": 621,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 10,
	        "SumMinChew": 5,
	        "beforeThreeSumRumina": 154,
	        "beforeThreeSumIntake": 230,
	        "score": 97,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 5,
	        "firmwareVersion": 57,
	        "createdAt": 1740465745,
	        "updatedAt": 1740469355
	    },
	    {
	        "id": 1725955,
	        "pastureId": 1,
	        "neckRingNumber": "10038",
	        "cowId": 94,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 2,
	        "intake": 0,
	        "inactive": 50,
	        "gasp": 0,
	        "other": 0,
	        "high": 532,
	        "active": 20,
	        "filterHigh": 23,
	        "filterRumina": 0,
	        "filterChew": 0,
	        "weekHigh": 1500,
	        "weekHighHabit": 287,
	        "weekRuminaHabit": 6,
	        "weekIntakeHabit": 35,
	        "weekChewHabit": 12,
	        "weekInactiveHabit": 35,
	        "weekOtherHabit": 0,
	        "changeHigh": -23,
	        "changeRumina": -100,
	        "changeChew": -100,
	        "changeAdjust": 0,
	        "changeFilter": -6,
	        "ruminaFilter": -12,
	        "chewFilter": -15,
	        "filterCorrect": 98,
	        "sumRumina": 10,
	        "sumIntake": 0,
	        "sumInactive": 679,
	        "sumActive": 124,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 3,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 8,
	        "beforeThreeSumIntake": 7,
	        "score": 67,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 5,
	        "firmwareVersion": 57,
	        "createdAt": 1740465775,
	        "updatedAt": 1740469385
	    },
	    {
	        "id": 1725957,
	        "pastureId": 1,
	        "neckRingNumber": "10055",
	        "cowId": 110,
	        "lact": 2,
	        "calvingAge": 62,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 24,
	        "intake": 39,
	        "inactive": 32,
	        "gasp": 0,
	        "other": 0,
	        "high": 1902,
	        "active": 63,
	        "filterHigh": 47,
	        "filterRumina": 15,
	        "filterChew": 15,
	        "weekHigh": 1500,
	        "weekHighHabit": 980,
	        "weekRuminaHabit": 3,
	        "weekIntakeHabit": 34,
	        "weekChewHabit": 14,
	        "weekInactiveHabit": 34,
	        "weekOtherHabit": 0,
	        "changeHigh": -71,
	        "changeRumina": 400,
	        "changeChew": 7,
	        "changeAdjust": 0,
	        "changeFilter": -21,
	        "ruminaFilter": 50,
	        "chewFilter": 2,
	        "filterCorrect": 95,
	        "sumRumina": 125,
	        "sumIntake": 208,
	        "sumInactive": 690,
	        "sumActive": 627,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 18,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 71,
	        "beforeThreeSumIntake": 279,
	        "score": 91,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 5,
	        "firmwareVersion": 57,
	        "createdAt": 1740465780,
	        "updatedAt": 1740469380
	    },
	    {
	        "id": 1725961,
	        "pastureId": 1,
	        "neckRingNumber": "10032",
	        "cowId": 88,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 40,
	        "intake": 34,
	        "inactive": 39,
	        "gasp": 0,
	        "other": 0,
	        "high": 1908,
	        "active": 62,
	        "filterHigh": 52,
	        "filterRumina": 25,
	        "filterChew": 25,
	        "weekHigh": 1500,
	        "weekHighHabit": 393,
	        "weekRuminaHabit": 5,
	        "weekIntakeHabit": 44,
	        "weekChewHabit": 16,
	        "weekInactiveHabit": 44,
	        "weekOtherHabit": 0,
	        "changeHigh": -29,
	        "changeRumina": 400,
	        "changeChew": 56,
	        "changeAdjust": 0,
	        "changeFilter": -7,
	        "ruminaFilter": 48,
	        "chewFilter": 17,
	        "filterCorrect": 97,
	        "sumRumina": 72,
	        "sumIntake": 184,
	        "sumInactive": 734,
	        "sumActive": 464,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 11,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 87,
	        "beforeThreeSumIntake": 206,
	        "score": 87,
	        "isMaxTime": 2,
	        "isShow": 2,
	        "recordCount": 5,
	        "firmwareVersion": 57,
	        "createdAt": 1740465815,
	        "updatedAt": 1740469420
	    },
	    {
	        "id": 1725965,
	        "pastureId": 1,
	        "neckRingNumber": "10053",
	        "cowId": 108,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 44,
	        "intake": 0,
	        "inactive": 60,
	        "gasp": 0,
	        "other": 0,
	        "high": 37,
	        "active": 0,
	        "filterHigh": 29,
	        "filterRumina": 30,
	        "filterChew": 30,
	        "weekHigh": 1500,
	        "weekHighHabit": 576,
	        "weekRuminaHabit": 14,
	        "weekIntakeHabit": 39,
	        "weekChewHabit": 29,
	        "weekInactiveHabit": 39,
	        "weekOtherHabit": 0,
	        "changeHigh": -45,
	        "changeRumina": 114,
	        "changeChew": 3,
	        "changeAdjust": 0,
	        "changeFilter": -11,
	        "ruminaFilter": 14,
	        "chewFilter": 1,
	        "filterCorrect": 96,
	        "sumRumina": 162,
	        "sumIntake": 274,
	        "sumInactive": 762,
	        "sumActive": 583,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 12,
	        "SumMinChew": 10,
	        "beforeThreeSumRumina": 201,
	        "beforeThreeSumIntake": 245,
	        "score": 95,
	        "isMaxTime": 2,
	        "isShow": 1,
	        "recordCount": 3,
	        "firmwareVersion": 57,
	        "createdAt": 1740466900,
	        "updatedAt": 1740466958
	    },
	    {
	        "id": 1725968,
	        "pastureId": 1,
	        "neckRingNumber": "10027",
	        "cowId": 30,
	        "lact": 0,
	        "calvingAge": 0,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 22,
	        "intake": 0,
	        "inactive": 60,
	        "gasp": 0,
	        "other": 0,
	        "high": 89,
	        "active": 6,
	        "filterHigh": 69,
	        "filterRumina": 15,
	        "filterChew": 15,
	        "weekHigh": 1500,
	        "weekHighHabit": 588,
	        "weekRuminaHabit": 14,
	        "weekIntakeHabit": 28,
	        "weekChewHabit": 25,
	        "weekInactiveHabit": 28,
	        "weekOtherHabit": 0,
	        "changeHigh": -42,
	        "changeRumina": 7,
	        "changeChew": -40,
	        "changeAdjust": 0,
	        "changeFilter": -10,
	        "ruminaFilter": 2,
	        "chewFilter": -12,
	        "filterCorrect": 94,
	        "sumRumina": 156,
	        "sumIntake": 300,
	        "sumInactive": 515,
	        "sumActive": 677,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 20,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 96,
	        "beforeThreeSumIntake": 316,
	        "score": 96,
	        "isMaxTime": 2,
	        "isShow": 1,
	        "recordCount": 3,
	        "firmwareVersion": 57,
	        "createdAt": 1740466925,
	        "updatedAt": 1740466958
	    },
	    {
	        "id": 1725973,
	        "pastureId": 1,
	        "neckRingNumber": "10028",
	        "cowId": 84,
	        "lact": 2,
	        "calvingAge": 300,
	        "activeTime": "2025-02-25 15:00:00",
	        "frameid": 7,
	        "heatDate": "2025-02-25",
	        "rumina": 14,
	        "intake": 36,
	        "inactive": 12,
	        "gasp": 0,
	        "other": 0,
	        "high": 1541,
	        "active": 50,
	        "filterHigh": 1187,
	        "filterRumina": 10,
	        "filterChew": 34,
	        "weekHigh": 1500,
	        "weekHighHabit": 203,
	        "weekRuminaHabit": 14,
	        "weekIntakeHabit": 36,
	        "weekChewHabit": 16,
	        "weekInactiveHabit": 36,
	        "weekOtherHabit": 0,
	        "changeHigh": 86,
	        "changeRumina": -29,
	        "changeChew": 113,
	        "changeAdjust": 0,
	        "changeFilter": 26,
	        "ruminaFilter": -9,
	        "chewFilter": 17,
	        "filterCorrect": 95,
	        "sumRumina": 127,
	        "sumIntake": 231,
	        "sumInactive": 791,
	        "sumActive": 567,
	        "sumMinHigh": -10000,
	        "sumMaxHigh": 16,
	        "SumMinChew": 0,
	        "beforeThreeSumRumina": 134,
	        "beforeThreeSumIntake": 243,
	        "score": 100,
	        "isMaxTime": 2,
	        "isShow": 1,
	        "recordCount": 3,
	        "firmwareVersion": 57,
	        "createdAt": 1740466940,
	        "updatedAt": 1740466958
	    }
	]`

	if err := json.Unmarshal([]byte(str), &neckActiveHabitList); err != nil {
		panic(err)
	}

	for _, habit := range neckActiveHabitList {
		cft := calculateCFT(habit)
		fmt.Println(habit.Id, cft)
	}*/

	activeTimeParse, _ := time.Parse(model.LayoutTime, "2025-03-04 01:00:00")
	println(activeTimeParse.Format(model.LayoutTime))
}

func recalculate(neckRingList []*model.NeckRingOriginal) []*model.NeckActiveHabit {
	originalMapData := make(map[string]*model.NeckRingOriginalMerge)
	// 合并成2个小时的
	for _, v := range neckRingList {
		xframeId := util.XFrameId(v.Frameid)
		mapKey := fmt.Sprintf("%s%s%s%s%d", v.NeckRingNumber, model.JoinKey, v.ActiveDate, model.JoinKey, xframeId) // 0001/2023-12-04/0 0001/2023-12-03/4
		if originalMapData[mapKey] == nil {
			originalMapData[mapKey] = new(model.NeckRingOriginalMerge)
		}
		originalMapData[mapKey].IsMageData(v, xframeId)
	}

	currTime := time.Now()
	res := make([]*model.NeckActiveHabit, 0)
	// 算平均值
	for k, v := range originalMapData {
		// 过滤掉合并后不等于6条数据
		if v.RecordCount > model.DefaultRecordCount {
			delete(originalMapData, k)
			continue
		} else if v.RecordCount < model.DefaultRecordCount {
			currMaxXframeId := util.FrameIdMapReverse[int32(currTime.Hour())]
			activeDateString := fmt.Sprintf("%s %02d:00:00", v.ActiveDate, v.XframeId*2+1)
			activeDate, _ := time.Parse(model.LayoutTime, activeDateString)
			if currMaxXframeId-v.XframeId <= 1 && currTime.Add(-1*time.Hour).Unix() < activeDate.Unix() {
				delete(originalMapData, k)
				continue
			}
		}
		v.SumAvg()
	}

	if len(originalMapData) <= 0 {
		return res
	}
	res = model.NeckRingOriginalMap(originalMapData).ForMatData()
	sort.Sort(model.NeckActiveHabitSlice(res))
	return res
}

func TestRecalculate(t *testing.T) {
	str := `[
    {
        "id": 39746398,
        "pastureId": 1,
        "uuid": "321434420250303101",
        "neckRingNumber": "3214344",
        "activeDate": "2025-03-03",
        "hours": 20,
        "frameid": 101,
        "rumina": 0,
        "intake": 18,
        "inactive": 0,
        "gasp": 0,
        "high": 669,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 59,
        "voltage": 297,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190705",
        "receiveNumber": "869701075190705",
        "createdAt": 1741074907,
        "updatedAt": 1741074907
    },
    {
        "id": 39746815,
        "pastureId": 1,
        "uuid": "321434420250303102",
        "neckRingNumber": "3214344",
        "activeDate": "2025-03-03",
        "hours": 20,
        "frameid": 102,
        "rumina": 0,
        "intake": 16,
        "inactive": 0,
        "gasp": 0,
        "high": 710,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 58,
        "voltage": 297,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190705",
        "receiveNumber": "869701075190705",
        "createdAt": 1741075214,
        "updatedAt": 1741075214
    },
    {
        "id": 39755830,
        "pastureId": 1,
        "uuid": "321434420250303103",
        "neckRingNumber": "3214344",
        "activeDate": "2025-03-03",
        "hours": 21,
        "frameid": 103,
        "rumina": 0,
        "intake": 15,
        "inactive": 0,
        "gasp": 0,
        "high": 681,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 58,
        "voltage": 297,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190705",
        "receiveNumber": "869701075190705",
        "createdAt": 1741075500,
        "updatedAt": 1741075500
    },
    {
        "id": 39757863,
        "pastureId": 1,
        "uuid": "321434420250303104",
        "neckRingNumber": "3214344",
        "activeDate": "2025-03-03",
        "hours": 21,
        "frameid": 104,
        "rumina": 2,
        "intake": 13,
        "inactive": 4,
        "gasp": 0,
        "high": 547,
        "active": 15,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 57,
        "voltage": 297,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190705",
        "receiveNumber": "869701075190705",
        "createdAt": 1741075778,
        "updatedAt": 1741075778
    },
    {
        "id": 39758419,
        "pastureId": 1,
        "uuid": "321434420250303105",
        "neckRingNumber": "3214344",
        "activeDate": "2025-03-03",
        "hours": 21,
        "frameid": 105,
        "rumina": 19,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 8,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 56,
        "voltage": 297,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190705",
        "receiveNumber": "869701075190705",
        "createdAt": 1741076414,
        "updatedAt": 1741076414
    },
    {
        "id": 39764857,
        "pastureId": 1,
        "uuid": "321434420250303105",
        "neckRingNumber": "3214344",
        "activeDate": "2025-03-03",
        "hours": 21,
        "frameid": 105,
        "rumina": 19,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 8,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 57,
        "voltage": 297,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190705",
        "receiveNumber": "869701075190705",
        "createdAt": 1741076699,
        "updatedAt": 1741076699
    },
    {
        "id": 39775243,
        "pastureId": 1,
        "uuid": "321434420250303106",
        "neckRingNumber": "3214344",
        "activeDate": "2025-03-03",
        "hours": 22,
        "frameid": 106,
        "rumina": 20,
        "intake": 0,
        "inactive": 13,
        "gasp": 0,
        "high": 44,
        "active": 7,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 57,
        "voltage": 297,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190705",
        "receiveNumber": "869701075190705",
        "createdAt": 1741078780,
        "updatedAt": 1741078780
    },
    {
        "id": 39712376,
        "pastureId": 1,
        "uuid": "105622025030471",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 71,
        "rumina": 7,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 6,
        "active": 0,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741070601,
        "updatedAt": 1741070601
    },
    {
        "id": 39712377,
        "pastureId": 1,
        "uuid": "105622025030472",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 72,
        "rumina": 17,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 8,
        "active": 0,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741070601,
        "updatedAt": 1741070601
    },
    {
        "id": 39741114,
        "pastureId": 1,
        "uuid": "105622025030473",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 73,
        "rumina": 14,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 6,
        "active": 0,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741074193,
        "updatedAt": 1741074193
    },
    {
        "id": 39741115,
        "pastureId": 1,
        "uuid": "105622025030474",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 74,
        "rumina": 16,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 18,
        "active": 1,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741074193,
        "updatedAt": 1741074193
    },
    {
        "id": 39741116,
        "pastureId": 1,
        "uuid": "105622025030475",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 75,
        "rumina": 0,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 16,
        "active": 1,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741074193,
        "updatedAt": 1741074193
    },
    {
        "id": 39770269,
        "pastureId": 1,
        "uuid": "105622025030476",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 76,
        "rumina": 0,
        "intake": 2,
        "inactive": 3,
        "gasp": 0,
        "high": 386,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741077796,
        "updatedAt": 1741077796
    },
    {
        "id": 39774441,
        "pastureId": 1,
        "uuid": "105622025030476",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 76,
        "rumina": 0,
        "intake": 2,
        "inactive": 3,
        "gasp": 0,
        "high": 386,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741078112,
        "updatedAt": 1741078112
    },
    {
        "id": 39770270,
        "pastureId": 1,
        "uuid": "105622025030481",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 81,
        "rumina": 0,
        "intake": 1,
        "inactive": 0,
        "gasp": 0,
        "high": 374,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741077796,
        "updatedAt": 1741077796
    },
    {
        "id": 39774442,
        "pastureId": 1,
        "uuid": "105622025030481",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 81,
        "rumina": 0,
        "intake": 1,
        "inactive": 0,
        "gasp": 0,
        "high": 374,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741078112,
        "updatedAt": 1741078112
    },
    {
        "id": 39770271,
        "pastureId": 1,
        "uuid": "105622025030482",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 82,
        "rumina": 1,
        "intake": 2,
        "inactive": 3,
        "gasp": 0,
        "high": 440,
        "active": 17,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741077796,
        "updatedAt": 1741077796
    },
    {
        "id": 39774443,
        "pastureId": 1,
        "uuid": "105622025030482",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 82,
        "rumina": 1,
        "intake": 2,
        "inactive": 3,
        "gasp": 0,
        "high": 440,
        "active": 17,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741078112,
        "updatedAt": 1741078112
    },
    {
        "id": 39798900,
        "pastureId": 1,
        "uuid": "105622025030483",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 83,
        "rumina": 4,
        "intake": 3,
        "inactive": 2,
        "gasp": 0,
        "high": 691,
        "active": 20,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741081392,
        "updatedAt": 1741081392
    },
    {
        "id": 39798901,
        "pastureId": 1,
        "uuid": "105622025030484",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 84,
        "rumina": 2,
        "intake": 3,
        "inactive": 0,
        "gasp": 0,
        "high": 468,
        "active": 17,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741081392,
        "updatedAt": 1741081392
    },
    {
        "id": 39798949,
        "pastureId": 1,
        "uuid": "105622025030485",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 85,
        "rumina": 1,
        "intake": 6,
        "inactive": 0,
        "gasp": 0,
        "high": 549,
        "active": 17,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741081395,
        "updatedAt": 1741081395
    },
    {
        "id": 39832313,
        "pastureId": 1,
        "uuid": "105622025030486",
        "neckRingNumber": "10562",
        "activeDate": "2025-03-04",
        "hours": 18,
        "frameid": 86,
        "rumina": 0,
        "intake": 16,
        "inactive": 0,
        "gasp": 0,
        "high": 674,
        "active": 20,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 301,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741085617,
        "updatedAt": 1741085617
    },
    {
        "id": 39712469,
        "pastureId": 1,
        "uuid": "105742025030471",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 71,
        "rumina": 0,
        "intake": 15,
        "inactive": 0,
        "gasp": 0,
        "high": 564,
        "active": 20,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741070601,
        "updatedAt": 1741070601
    },
    {
        "id": 39712470,
        "pastureId": 1,
        "uuid": "105742025030472",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 72,
        "rumina": 0,
        "intake": 0,
        "inactive": 13,
        "gasp": 0,
        "high": 190,
        "active": 7,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741070601,
        "updatedAt": 1741070601
    },
    {
        "id": 39741207,
        "pastureId": 1,
        "uuid": "105742025030473",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 73,
        "rumina": 18,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 29,
        "active": 1,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741074196,
        "updatedAt": 1741074196
    },
    {
        "id": 39741208,
        "pastureId": 1,
        "uuid": "105742025030474",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 74,
        "rumina": 20,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 31,
        "active": 0,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741074196,
        "updatedAt": 1741074196
    },
    {
        "id": 39741209,
        "pastureId": 1,
        "uuid": "105742025030475",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 75,
        "rumina": 11,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 58,
        "active": 3,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741074196,
        "updatedAt": 1741074196
    },
    {
        "id": 39774444,
        "pastureId": 1,
        "uuid": "105742025030476",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 76,
        "rumina": 1,
        "intake": 0,
        "inactive": 15,
        "gasp": 0,
        "high": 391,
        "active": 9,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741078112,
        "updatedAt": 1741078112
    },
    {
        "id": 39770362,
        "pastureId": 1,
        "uuid": "105742025030476",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 76,
        "rumina": 1,
        "intake": 0,
        "inactive": 15,
        "gasp": 0,
        "high": 391,
        "active": 9,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741077796,
        "updatedAt": 1741077796
    },
    {
        "id": 39774445,
        "pastureId": 1,
        "uuid": "105742025030481",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 81,
        "rumina": 0,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 391,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741078112,
        "updatedAt": 1741078112
    },
    {
        "id": 39770363,
        "pastureId": 1,
        "uuid": "105742025030481",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 81,
        "rumina": 0,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 391,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741077796,
        "updatedAt": 1741077796
    },
    {
        "id": 39774446,
        "pastureId": 1,
        "uuid": "105742025030482",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 82,
        "rumina": 0,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 323,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741078112,
        "updatedAt": 1741078112
    },
    {
        "id": 39770364,
        "pastureId": 1,
        "uuid": "105742025030482",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 82,
        "rumina": 0,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 323,
        "active": 13,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741077796,
        "updatedAt": 1741077796
    },
    {
        "id": 39799040,
        "pastureId": 1,
        "uuid": "105742025030483",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 83,
        "rumina": 0,
        "intake": 1,
        "inactive": 0,
        "gasp": 0,
        "high": 691,
        "active": 20,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741081395,
        "updatedAt": 1741081395
    },
    {
        "id": 39799041,
        "pastureId": 1,
        "uuid": "105742025030484",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 84,
        "rumina": 1,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 621,
        "active": 20,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741081395,
        "updatedAt": 1741081395
    },
    {
        "id": 39799042,
        "pastureId": 1,
        "uuid": "105742025030485",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 85,
        "rumina": 6,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 518,
        "active": 20,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741081395,
        "updatedAt": 1741081395
    },
    {
        "id": 39827555,
        "pastureId": 1,
        "uuid": "105742025030486",
        "neckRingNumber": "10574",
        "activeDate": "2025-03-04",
        "hours": 18,
        "frameid": 86,
        "rumina": 0,
        "intake": 13,
        "inactive": 0,
        "gasp": 0,
        "high": 707,
        "active": 20,
        "other": 0,
        "firmwareVersion": 57,
        "hardwareVersion": 10,
        "remain": 6,
        "voltage": 306,
        "restartReason": 0,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075191117",
        "receiveNumber": "869701075191117",
        "createdAt": 1741085005,
        "updatedAt": 1741085005
    },
    {
        "id": 39861751,
        "pastureId": 1,
        "uuid": "1070420250304101",
        "neckRingNumber": "10704",
        "activeDate": "2025-03-04",
        "hours": 20,
        "frameid": 101,
        "rumina": 2,
        "intake": 5,
        "inactive": 11,
        "gasp": 0,
        "high": 228,
        "active": 9,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741090446,
        "updatedAt": 1741090446
    },
    {
        "id": 39870079,
        "pastureId": 1,
        "uuid": "1070420250304102",
        "neckRingNumber": "10704",
        "activeDate": "2025-03-04",
        "hours": 20,
        "frameid": 102,
        "rumina": 20,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 74,
        "active": 14,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741091644,
        "updatedAt": 1741091644
    },
    {
        "id": 39870180,
        "pastureId": 1,
        "uuid": "1070420250304102",
        "neckRingNumber": "10704",
        "activeDate": "2025-03-04",
        "hours": 20,
        "frameid": 102,
        "rumina": 20,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 74,
        "active": 14,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741091886,
        "updatedAt": 1741091886
    },
    {
        "id": 39878730,
        "pastureId": 1,
        "uuid": "1070420250304103",
        "neckRingNumber": "10704",
        "activeDate": "2025-03-04",
        "hours": 21,
        "frameid": 103,
        "rumina": 15,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 53,
        "active": 13,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741092840,
        "updatedAt": 1741092840
    },
    {
        "id": 39890324,
        "pastureId": 1,
        "uuid": "1070420250304104",
        "neckRingNumber": "10704",
        "activeDate": "2025-03-04",
        "hours": 21,
        "frameid": 104,
        "rumina": 0,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 15,
        "active": 1,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741094041,
        "updatedAt": 1741094041
    },
    {
        "id": 39898562,
        "pastureId": 1,
        "uuid": "1070420250304105",
        "neckRingNumber": "10704",
        "activeDate": "2025-03-04",
        "hours": 21,
        "frameid": 105,
        "rumina": 13,
        "intake": 0,
        "inactive": 20,
        "gasp": 5,
        "high": 9,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741095241,
        "updatedAt": 1741095241
    },
    {
        "id": 39907240,
        "pastureId": 1,
        "uuid": "1070420250304106",
        "neckRingNumber": "10704",
        "activeDate": "2025-03-04",
        "hours": 22,
        "frameid": 106,
        "rumina": 20,
        "intake": 0,
        "inactive": 20,
        "gasp": 3,
        "high": 29,
        "active": 1,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741096444,
        "updatedAt": 1741096444
    },
    {
        "id": 39765983,
        "pastureId": 1,
        "uuid": "107092025030481",
        "neckRingNumber": "10709",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 81,
        "rumina": 14,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 7,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 305,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741076914,
        "updatedAt": 1741076914
    },
    {
        "id": 39766488,
        "pastureId": 1,
        "uuid": "107092025030482",
        "neckRingNumber": "10709",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 82,
        "rumina": 13,
        "intake": 0,
        "inactive": 12,
        "gasp": 0,
        "high": 119,
        "active": 5,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 305,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741077242,
        "updatedAt": 1741077242
    },
    {
        "id": 39775232,
        "pastureId": 1,
        "uuid": "107092025030483",
        "neckRingNumber": "10709",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 83,
        "rumina": 1,
        "intake": 10,
        "inactive": 0,
        "gasp": 0,
        "high": 412,
        "active": 18,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 305,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741078688,
        "updatedAt": 1741078688
    },
    {
        "id": 39794774,
        "pastureId": 1,
        "uuid": "107092025030484",
        "neckRingNumber": "10709",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 84,
        "rumina": 0,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 372,
        "active": 15,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 305,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741080504,
        "updatedAt": 1741080504
    },
    {
        "id": 39786688,
        "pastureId": 1,
        "uuid": "107092025030484",
        "neckRingNumber": "10709",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 84,
        "rumina": 0,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 372,
        "active": 15,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 305,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741079623,
        "updatedAt": 1741079623
    },
    {
        "id": 39795227,
        "pastureId": 1,
        "uuid": "107092025030485",
        "neckRingNumber": "10709",
        "activeDate": "2025-03-04",
        "hours": 17,
        "frameid": 85,
        "rumina": 0,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 563,
        "active": 18,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 305,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741080842,
        "updatedAt": 1741080842
    },
    {
        "id": 39803763,
        "pastureId": 1,
        "uuid": "107092025030486",
        "neckRingNumber": "10709",
        "activeDate": "2025-03-04",
        "hours": 18,
        "frameid": 86,
        "rumina": 7,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 124,
        "active": 6,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 305,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741081979,
        "updatedAt": 1741081979
    },
    {
        "id": 39585880,
        "pastureId": 1,
        "uuid": "107102025030451",
        "neckRingNumber": "10710",
        "activeDate": "2025-03-04",
        "hours": 10,
        "frameid": 51,
        "rumina": 15,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 139,
        "active": 14,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741054411,
        "updatedAt": 1741054411
    },
    {
        "id": 39593663,
        "pastureId": 1,
        "uuid": "107102025030452",
        "neckRingNumber": "10710",
        "activeDate": "2025-03-04",
        "hours": 10,
        "frameid": 52,
        "rumina": 9,
        "intake": 7,
        "inactive": 0,
        "gasp": 0,
        "high": 346,
        "active": 15,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741055643,
        "updatedAt": 1741055643
    },
    {
        "id": 39602483,
        "pastureId": 1,
        "uuid": "107102025030453",
        "neckRingNumber": "10710",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 53,
        "rumina": 0,
        "intake": 16,
        "inactive": 0,
        "gasp": 0,
        "high": 524,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741056836,
        "updatedAt": 1741056836
    },
    {
        "id": 39614495,
        "pastureId": 1,
        "uuid": "107102025030454",
        "neckRingNumber": "10710",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 54,
        "rumina": 0,
        "intake": 17,
        "inactive": 0,
        "gasp": 0,
        "high": 558,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741058260,
        "updatedAt": 1741058260
    },
    {
        "id": 39614198,
        "pastureId": 1,
        "uuid": "107102025030454",
        "neckRingNumber": "10710",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 54,
        "rumina": 0,
        "intake": 17,
        "inactive": 0,
        "gasp": 0,
        "high": 558,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741058020,
        "updatedAt": 1741058020
    },
    {
        "id": 39621998,
        "pastureId": 1,
        "uuid": "107102025030455",
        "neckRingNumber": "10710",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 55,
        "rumina": 0,
        "intake": 3,
        "inactive": 6,
        "gasp": 0,
        "high": 141,
        "active": 7,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741059237,
        "updatedAt": 1741059237
    },
    {
        "id": 39631255,
        "pastureId": 1,
        "uuid": "107102025030456",
        "neckRingNumber": "10710",
        "activeDate": "2025-03-04",
        "hours": 12,
        "frameid": 56,
        "rumina": 0,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 4,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741060691,
        "updatedAt": 1741060691
    },
    {
        "id": 39919093,
        "pastureId": 1,
        "uuid": "1071820250304111",
        "neckRingNumber": "10718",
        "activeDate": "2025-03-04",
        "hours": 22,
        "frameid": 111,
        "rumina": 19,
        "intake": 0,
        "inactive": 15,
        "gasp": 0,
        "high": 108,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741097888,
        "updatedAt": 1741097888
    },
    {
        "id": 39926993,
        "pastureId": 1,
        "uuid": "1071820250304112",
        "neckRingNumber": "10718",
        "activeDate": "2025-03-04",
        "hours": 22,
        "frameid": 112,
        "rumina": 15,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 48,
        "active": 8,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741098765,
        "updatedAt": 1741098765
    },
    {
        "id": 39936309,
        "pastureId": 1,
        "uuid": "1071820250304113",
        "neckRingNumber": "10718",
        "activeDate": "2025-03-04",
        "hours": 23,
        "frameid": 113,
        "rumina": 0,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 25,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741100289,
        "updatedAt": 1741100289
    },
    {
        "id": 39935620,
        "pastureId": 1,
        "uuid": "1071820250304113",
        "neckRingNumber": "10718",
        "activeDate": "2025-03-04",
        "hours": 23,
        "frameid": 113,
        "rumina": 0,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 25,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741099964,
        "updatedAt": 1741099964
    },
    {
        "id": 39947890,
        "pastureId": 1,
        "uuid": "1071820250304114",
        "neckRingNumber": "10718",
        "activeDate": "2025-03-04",
        "hours": 23,
        "frameid": 114,
        "rumina": 0,
        "intake": 1,
        "inactive": 19,
        "gasp": 0,
        "high": 96,
        "active": 6,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741101165,
        "updatedAt": 1741101165
    },
    {
        "id": 39956178,
        "pastureId": 1,
        "uuid": "1071820250304115",
        "neckRingNumber": "10718",
        "activeDate": "2025-03-04",
        "hours": 23,
        "frameid": 115,
        "rumina": 0,
        "intake": 18,
        "inactive": 0,
        "gasp": 0,
        "high": 433,
        "active": 19,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741102365,
        "updatedAt": 1741102365
    },
    {
        "id": 39964758,
        "pastureId": 1,
        "uuid": "1071820250304116",
        "neckRingNumber": "10718",
        "activeDate": "2025-03-04",
        "hours": 24,
        "frameid": 116,
        "rumina": 0,
        "intake": 14,
        "inactive": 0,
        "gasp": 0,
        "high": 448,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741103565,
        "updatedAt": 1741103565
    },
    {
        "id": 39918690,
        "pastureId": 1,
        "uuid": "1072320250304111",
        "neckRingNumber": "10723",
        "activeDate": "2025-03-04",
        "hours": 22,
        "frameid": 111,
        "rumina": 0,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 7,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 174,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741097565,
        "updatedAt": 1741097565
    },
    {
        "id": 39927106,
        "pastureId": 1,
        "uuid": "1072320250304112",
        "neckRingNumber": "10723",
        "activeDate": "2025-03-04",
        "hours": 22,
        "frameid": 112,
        "rumina": 3,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 23,
        "active": 2,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 174,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741098781,
        "updatedAt": 1741098781
    },
    {
        "id": 39927434,
        "pastureId": 1,
        "uuid": "1072320250304112",
        "neckRingNumber": "10723",
        "activeDate": "2025-03-04",
        "hours": 22,
        "frameid": 112,
        "rumina": 3,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 23,
        "active": 2,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 174,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741099092,
        "updatedAt": 1741099092
    },
    {
        "id": 39935746,
        "pastureId": 1,
        "uuid": "1072320250304113",
        "neckRingNumber": "10723",
        "activeDate": "2025-03-04",
        "hours": 23,
        "frameid": 113,
        "rumina": 15,
        "intake": 4,
        "inactive": 16,
        "gasp": 0,
        "high": 178,
        "active": 5,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 174,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741099983,
        "updatedAt": 1741099983
    },
    {
        "id": 39951142,
        "pastureId": 1,
        "uuid": "1072320250304114",
        "neckRingNumber": "10723",
        "activeDate": "2025-03-04",
        "hours": 23,
        "frameid": 114,
        "rumina": 2,
        "intake": 17,
        "inactive": 0,
        "gasp": 0,
        "high": 614,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 174,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741101771,
        "updatedAt": 1741101771
    },
    {
        "id": 39956291,
        "pastureId": 1,
        "uuid": "1072320250304115",
        "neckRingNumber": "10723",
        "activeDate": "2025-03-04",
        "hours": 23,
        "frameid": 115,
        "rumina": 0,
        "intake": 20,
        "inactive": 0,
        "gasp": 0,
        "high": 628,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 174,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741102387,
        "updatedAt": 1741102387
    },
    {
        "id": 39964870,
        "pastureId": 1,
        "uuid": "1072320250304116",
        "neckRingNumber": "10723",
        "activeDate": "2025-03-04",
        "hours": 24,
        "frameid": 116,
        "rumina": 0,
        "intake": 9,
        "inactive": 0,
        "gasp": 0,
        "high": 452,
        "active": 19,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 174,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741103582,
        "updatedAt": 1741103582
    },
    {
        "id": 39643327,
        "pastureId": 1,
        "uuid": "107252025030461",
        "neckRingNumber": "10725",
        "activeDate": "2025-03-04",
        "hours": 12,
        "frameid": 61,
        "rumina": 0,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 18,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741061861,
        "updatedAt": 1741061861
    },
    {
        "id": 39651606,
        "pastureId": 1,
        "uuid": "107252025030462",
        "neckRingNumber": "10725",
        "activeDate": "2025-03-04",
        "hours": 12,
        "frameid": 62,
        "rumina": 0,
        "intake": 2,
        "inactive": 17,
        "gasp": 0,
        "high": 115,
        "active": 3,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741063089,
        "updatedAt": 1741063089
    },
    {
        "id": 39660185,
        "pastureId": 1,
        "uuid": "107252025030463",
        "neckRingNumber": "10725",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 63,
        "rumina": 0,
        "intake": 15,
        "inactive": 0,
        "gasp": 0,
        "high": 734,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741064294,
        "updatedAt": 1741064294
    },
    {
        "id": 39659988,
        "pastureId": 1,
        "uuid": "107252025030463",
        "neckRingNumber": "10725",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 63,
        "rumina": 0,
        "intake": 15,
        "inactive": 0,
        "gasp": 0,
        "high": 734,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741064041,
        "updatedAt": 1741064041
    },
    {
        "id": 39671876,
        "pastureId": 1,
        "uuid": "107252025030464",
        "neckRingNumber": "10725",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 64,
        "rumina": 2,
        "intake": 17,
        "inactive": 0,
        "gasp": 0,
        "high": 589,
        "active": 19,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741065521,
        "updatedAt": 1741065521
    },
    {
        "id": 39679662,
        "pastureId": 1,
        "uuid": "107252025030465",
        "neckRingNumber": "10725",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 65,
        "rumina": 0,
        "intake": 20,
        "inactive": 0,
        "gasp": 0,
        "high": 607,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741066422,
        "updatedAt": 1741066422
    },
    {
        "id": 39688282,
        "pastureId": 1,
        "uuid": "107252025030466",
        "neckRingNumber": "10725",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 66,
        "rumina": 4,
        "intake": 7,
        "inactive": 1,
        "gasp": 0,
        "high": 470,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741067578,
        "updatedAt": 1741067578
    },
    {
        "id": 39699766,
        "pastureId": 1,
        "uuid": "107672025030471",
        "neckRingNumber": "10767",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 71,
        "rumina": 0,
        "intake": 19,
        "inactive": 0,
        "gasp": 0,
        "high": 600,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741068766,
        "updatedAt": 1741068766
    },
    {
        "id": 39708539,
        "pastureId": 1,
        "uuid": "107672025030472",
        "neckRingNumber": "10767",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 72,
        "rumina": 0,
        "intake": 2,
        "inactive": 0,
        "gasp": 0,
        "high": 337,
        "active": 16,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741070036,
        "updatedAt": 1741070036
    },
    {
        "id": 39717751,
        "pastureId": 1,
        "uuid": "107672025030473",
        "neckRingNumber": "10767",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 73,
        "rumina": 4,
        "intake": 8,
        "inactive": 0,
        "gasp": 0,
        "high": 45,
        "active": 3,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741071486,
        "updatedAt": 1741071486
    },
    {
        "id": 39717511,
        "pastureId": 1,
        "uuid": "107672025030473",
        "neckRingNumber": "10767",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 73,
        "rumina": 4,
        "intake": 8,
        "inactive": 0,
        "gasp": 0,
        "high": 45,
        "active": 3,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741071239,
        "updatedAt": 1741071239
    },
    {
        "id": 39729605,
        "pastureId": 1,
        "uuid": "107672025030474",
        "neckRingNumber": "10767",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 74,
        "rumina": 14,
        "intake": 5,
        "inactive": 0,
        "gasp": 0,
        "high": 241,
        "active": 18,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741072723,
        "updatedAt": 1741072723
    },
    {
        "id": 39737760,
        "pastureId": 1,
        "uuid": "107672025030475",
        "neckRingNumber": "10767",
        "activeDate": "2025-03-04",
        "hours": 15,
        "frameid": 75,
        "rumina": 15,
        "intake": 0,
        "inactive": 19,
        "gasp": 0,
        "high": 34,
        "active": 1,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741073627,
        "updatedAt": 1741073627
    },
    {
        "id": 39746321,
        "pastureId": 1,
        "uuid": "107672025030476",
        "neckRingNumber": "10767",
        "activeDate": "2025-03-04",
        "hours": 16,
        "frameid": 76,
        "rumina": 20,
        "intake": 0,
        "inactive": 18,
        "gasp": 0,
        "high": 94,
        "active": 4,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741074841,
        "updatedAt": 1741074841
    },
    {
        "id": 39585903,
        "pastureId": 1,
        "uuid": "107682025030451",
        "neckRingNumber": "10768",
        "activeDate": "2025-03-04",
        "hours": 10,
        "frameid": 51,
        "rumina": 2,
        "intake": 11,
        "inactive": 0,
        "gasp": 0,
        "high": 542,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741054411,
        "updatedAt": 1741054411
    },
    {
        "id": 39593688,
        "pastureId": 1,
        "uuid": "107682025030452",
        "neckRingNumber": "10768",
        "activeDate": "2025-03-04",
        "hours": 10,
        "frameid": 52,
        "rumina": 0,
        "intake": 13,
        "inactive": 0,
        "gasp": 0,
        "high": 543,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741055643,
        "updatedAt": 1741055643
    },
    {
        "id": 39602507,
        "pastureId": 1,
        "uuid": "107682025030453",
        "neckRingNumber": "10768",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 53,
        "rumina": 12,
        "intake": 3,
        "inactive": 0,
        "gasp": 0,
        "high": 227,
        "active": 11,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741056836,
        "updatedAt": 1741056836
    },
    {
        "id": 39614221,
        "pastureId": 1,
        "uuid": "107682025030454",
        "neckRingNumber": "10768",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 54,
        "rumina": 16,
        "intake": 0,
        "inactive": 17,
        "gasp": 1,
        "high": 73,
        "active": 4,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741058020,
        "updatedAt": 1741058020
    },
    {
        "id": 39614498,
        "pastureId": 1,
        "uuid": "107682025030454",
        "neckRingNumber": "10768",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 54,
        "rumina": 16,
        "intake": 0,
        "inactive": 17,
        "gasp": 1,
        "high": 73,
        "active": 4,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741058260,
        "updatedAt": 1741058260
    },
    {
        "id": 39622024,
        "pastureId": 1,
        "uuid": "107682025030455",
        "neckRingNumber": "10768",
        "activeDate": "2025-03-04",
        "hours": 11,
        "frameid": 55,
        "rumina": 20,
        "intake": 0,
        "inactive": 20,
        "gasp": 0,
        "high": 6,
        "active": 1,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741059237,
        "updatedAt": 1741059237
    },
    {
        "id": 39631088,
        "pastureId": 1,
        "uuid": "107682025030456",
        "neckRingNumber": "10768",
        "activeDate": "2025-03-04",
        "hours": 12,
        "frameid": 56,
        "rumina": 20,
        "intake": 0,
        "inactive": 20,
        "gasp": 12,
        "high": 0,
        "active": 0,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 300,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741060454,
        "updatedAt": 1741060454
    },
    {
        "id": 39643330,
        "pastureId": 1,
        "uuid": "107902025030461",
        "neckRingNumber": "10790",
        "activeDate": "2025-03-04",
        "hours": 12,
        "frameid": 61,
        "rumina": 6,
        "intake": 5,
        "inactive": 0,
        "gasp": 0,
        "high": 157,
        "active": 14,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741061861,
        "updatedAt": 1741061861
    },
    {
        "id": 39651445,
        "pastureId": 1,
        "uuid": "107902025030462",
        "neckRingNumber": "10790",
        "activeDate": "2025-03-04",
        "hours": 12,
        "frameid": 62,
        "rumina": 16,
        "intake": 4,
        "inactive": 0,
        "gasp": 0,
        "high": 45,
        "active": 6,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741062766,
        "updatedAt": 1741062766
    },
    {
        "id": 39659991,
        "pastureId": 1,
        "uuid": "107902025030463",
        "neckRingNumber": "10790",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 63,
        "rumina": 7,
        "intake": 4,
        "inactive": 0,
        "gasp": 0,
        "high": 355,
        "active": 17,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741064041,
        "updatedAt": 1741064041
    },
    {
        "id": 39671879,
        "pastureId": 1,
        "uuid": "107902025030464",
        "neckRingNumber": "10790",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 64,
        "rumina": 0,
        "intake": 20,
        "inactive": 0,
        "gasp": 0,
        "high": 495,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741065521,
        "updatedAt": 1741065521
    },
    {
        "id": 39675509,
        "pastureId": 1,
        "uuid": "107902025030464",
        "neckRingNumber": "10790",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 64,
        "rumina": 0,
        "intake": 20,
        "inactive": 0,
        "gasp": 0,
        "high": 495,
        "active": 20,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 1,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741065787,
        "updatedAt": 1741065787
    },
    {
        "id": 39710887,
        "pastureId": 1,
        "uuid": "107902025030465",
        "neckRingNumber": "10790",
        "activeDate": "2025-03-04",
        "hours": 13,
        "frameid": 65,
        "rumina": 0,
        "intake": 6,
        "inactive": 0,
        "gasp": 0,
        "high": 452,
        "active": 19,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 4,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741070530,
        "updatedAt": 1741070530
    },
    {
        "id": 39712370,
        "pastureId": 1,
        "uuid": "107902025030466",
        "neckRingNumber": "10790",
        "activeDate": "2025-03-04",
        "hours": 14,
        "frameid": 66,
        "rumina": 6,
        "intake": 0,
        "inactive": 0,
        "gasp": 0,
        "high": 209,
        "active": 8,
        "other": 0,
        "firmwareVersion": 55,
        "hardwareVersion": 0,
        "remain": 3,
        "voltage": 301,
        "restartReason": 158,
        "upper": 0,
        "ActiveDateTimeType": 1,
        "isShow": 2,
        "imei": "869701075190853",
        "receiveNumber": "869701075190853",
        "createdAt": 1741070598,
        "updatedAt": 1741070598
    }
]`

	neckRingList := make([]*model.NeckRingOriginal, 0)
	if err := json.Unmarshal([]byte(str), &neckRingList); err != nil {
		panic(err)
	}

	neckRingList = RemoveDuplicates(neckRingList)
	data := recalculate(neckRingList)
	b, _ := json.Marshal(data)
	fmt.Println(string(b))
}

func TestIndex(t *testing.T) {
	ActiveTime := "2025-03-13 13:00:00"
	loc, _ := time.LoadLocation("Local")
	activeTime, _ := time.ParseInLocation(model.LayoutTime, ActiveTime, loc)
	fmt.Println("activeTime", activeTime.Unix())
	for i := 0; i < 7; i++ {
		hours := time.Now().Sub(activeTime).Hours()
		if i != model.DefaultRecordCount && int64(hours) < 8 {
			fmt.Println("i", i, "hours", int64(hours))
		} else {
			fmt.Println("j", i, "hours", int64(hours))
		}
	}
}
